% creates fig 10.19. CL of high- and mid-freq. compensated plant
%

% Ken Dutton 1994
%

% check that fig10_17.m has been run to generate data
echo off
if ~exist('kh') | ~exist('frh') | ~exist('ap') | ~exist('dp')
   disp(' ')
   disp('Running fig10_17 first to generate data - please wait')
   disp(' ')
   fig10_17   % run it now - not run before
end
%
% find index of first freq. greater than 0.15 rad/s
index=max(find(w<=0.15));
w015=w(index) % output to check
%
% design k2
disp('LTF of approx. comm. controller element (2,2):')
[kn,kd]=phlag(-15,0.35)
disp('Press any key to continue')
pause
%
% set k1 = s/s (must be dynamic, even though we want k1=1)
k1n=[1  0];
k1d=[1  0];
kn=[k1n;kn];     % arrange into the form required by facc
kd=[k1d;kd];
%
% Now design the ACC as [ka,kb,kc,kd]):
[ka,kb,kc,kd]=facc(w,frh,index,kn,kd);  % (w, frh from before)
%
% Use the fmulf command to cascade the MVFR representation of the 
% approx. commutative controlller with the MVFR matrix of the h.f.-
% compensated plant, rather than the fmul command (which only works
% with one MVFR matrix and a constant matrix). Again note that we
% work against the signal flow:
frk=mv2fr(ka,kb,kc,kd,w);   % obtain the MVFR matrix of latest compensator
frm=fmulf(w,frh,frk);       % MVFR of m.f.-compensated system fwd. path
clm=feig(w,frm);            % calculate CLoci of m.f.-compensated system
%
% the two plots cross data sets between w(18) and w(19). csort does not
% correct this, so we do it manually (just makes the plots neater):
rws=length(w);
fred=clm(19:rws,1);
clm(19:rws,1)=clm(19:rws,2);
clm(19:rws,2)=fred;
plotbode(w,clm),title('C.L. after high and mid freq. comp.');pause
%
% last line fine, but next lines plot separately for book
%[mag,pha]=r2p(clm);
%semilogx(w,20*log10(mag));grid
%pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_19a
%
% matlab 3.5 print:
%meta fig10_19a
%!gpp fig10_19a /dhpgl /ol
%
%semilogx(w,pha),grid
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_19b
%
% matlab 3.5 print:
%meta fig10_19b
%!gpp fig10_19b /dhpgl /ol
%
% Now build the state-space model for simulation:
%cascade Kh with the open loop plant
[as,bs,cs,ds]=mvser([],[],[],kh,ap,bp,cp,dp);
% swap for the next 3 lines for i/ps to be displayed (and alter 1 below)
%ci=[cp;zeros(2,max(size(cp)))];
%di=[dp;eye(2)];
%[as,bs,cs,ds]=series([],[],[],kh,ap,bp,ci,di);
%
[am,bm,cm,dm]=mvser(ka,kb,kc,kd,as,bs,cs,ds); % Cascade ACC w. hf-comp. plant
[a,b,c,d]=mvfb(am,bm,cm,dm,[],[],[],eye(2));  % add UNF loops 
% use next line instead if i/ps were included with the 3 linesabove
%[a,b,c,d]=feedback(am,bm,cm,dm,[],[],[],eye(2),-[1  2],[1  2]);  % add UNF loops 
%
t=[0:0.04:4];  %  time vector for plots
mv2step                        % simulations using m-file defined earlier
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_19c
%
% matlab 3.5 print:
%meta fig10_19c
%!gpp fig10_19c /dhpgl /ol
