% creates fig 10.20. - CL of overall compensated plant

% Ken Dutton 1994
%

% check that fig10_19.m has been run to generate data
echo off
if ~exist('frm') | ~exist('kh') | ~exist('ap') | ~exist('ka')
   disp(' ')
   disp('Running fig10_19 first to generate data - please wait')
   disp(' ')
   fig10_19  % run it now - not run before
end
disp(' ')
disp('working - please wait')
%
% input TFM for dc compensator
kdcnum=[1  0.1  0  0;0  0  1  0.1]; % polynomial num. matrix for compensator
kdccomden=[1  0];                % common denominator of compensator
[dca,dcb,dcc,dcd]=mvtf2ss(kdcnum,kdccomden); % convert compensator to s.space
%
frk=mv2fr(dca,dcb,dcc,dcd,w);   % obtain MVFR matrix of dc compensator
%
% Use fmulf command to cascade dc compensator MVFR matrix with MVFR matrix of 
% mid-freq.-compensated plant:
frl=fmulf(w,frm,frk);       % MVFR of overall-compensated system fwd. path
clm=feig(w,frl);            % calculate CLoci of overall-compensated system
%
% the two plots cross data sets between w(18) and w(19). csort does not
% correct this, so we do it manually (just makes plots neater):
rws=length(w);
fred=clm(19:rws,1);
clm(19:rws,1)=clm(19:rws,2);
clm(19:rws,2)=fred;
%
plotbode(w,clm),title('C.L. after low freq. comp.');pause
%
% last line fine, but next lines plot magnitude separately for book
%[mag,pha]=r2p(clm);
%semilogx(w,20*log10(mag));grid
%pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_20a
%
% matlab 3.5 print:
%meta fig10_20a
%!gpp fig10_20a /dhpgl /ol
%
% clear some memory
clear cl clh clm
clear frh frk frl fred
clear n11 n12 n21 n22 d11 d12 d21 d22 num11 num12 num21 num22
clear mag pha y1 y2 t
clear a b c d al bl cl dl
pack
%
% Now build the state-space model for simulation:
[as,bs,cs,ds]=mvser([],[],[],kh,ap,bp,cp,dp); %cascade Kh with o/l plant
% swap for next 3 lines if i/ps are to be displayed (and alter 1 line below)
%ci=[cp;zeros(2,max(size(cp)))];
%di=[dp;eye(2)];
%[as,bs,cs,ds]=series([],[],[],kh,ap,bp,ci,di);
%
[am,bm,cm,dm]=mvser(ka,kb,kc,kd,as,bs,cs,ds); % Cascade ACC w. hf-comp. plant
[al,bl,cl,dl]=mvser(dca,dcb,dcc,dcd,am,bm,cm,dm);  % cascade dc comp.
[a,b,c,d]=mvfb(al,bl,cl,dl,[],[],[],eye(2));  % add UNF loops 
% use next line instead if i/ps were included using 3 lines above
%[a,b,c,d]=feedback(al,bl,cl,dl,[],[],[],eye(2),-[1  2],[1  2]);  % add UNF 
%
t=[0:0.03:3];  %  time vector for plots
mv2step        % simulate
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_20b
%
% matlab 3.5 print:
%meta fig10_20b
%!gpp fig10_20b /dhpgl /ol
%
%
% clear some memory
clear mag pha y1 y2 t
clear as bs cs ds al bl cl dl a b c d
clear a0 b0 c0 d0 dca dcb dcc dcd
pack
%
% Now repeat the process with the compensator gains multiplied by
% diag(0.18  0.8)
kdcnum=diag([0.18  0.8])*kdcnum;  % multiply numerator matrix by gains
[dca,dcb,dcc,dcd]=mvtf2ss(kdcnum,kdccomden); % convert compensator to s.space
%
frk=mv2fr(dca,dcb,dcc,dcd,w);   % MVFR matrix of latest compensator
frl=fmulf(w,frm,frk);       % MVFR of overall-compensated system fwd. path
clm=feig(w,frl);            % calculate CLoci of overall-compensated system
%
plotbode(w,clm),title('C.L. after all comp.');pause
%
% clear some memory
clear clh clm
clear frh frk frl
clear mag pha y1 y2 t
pack
%
% Now build the state-space model for simulation:
[as,bs,cs,ds]=mvser([],[],[],kh,ap,bp,cp,dp); %cascade Kh with o/l plant
% swap for next 3 lines if i/ps are to be displayed, and alter 1 line below
%ci=[cp;zeros(2,max(size(cp)))];
%di=[dp;eye(2)];
%[as,bs,cs,ds]=series([],[],[],kh,ap,bp,ci,di);
%
[am,bm,cm,dm]=mvser(ka,kb,kc,kd,as,bs,cs,ds); % Cascade ACC w. hf-comp. plant
[al,bl,cl,dl]=mvser(dca,dcb,dcc,dcd,am,bm,cm,dm);  % cascade dc comp.
[a,b,c,d]=mvfb(al,bl,cl,dl,[],[],[],eye(2));  % add UNF loops 
% use next line instead if i/ps were included using 3 lines above
%[a,b,c,d]=feedback(al,bl,cl,dl,[],[],[],eye(2),-[1  2],[1  2]);  % add UNF 
%
t=[0:0.06:6];  %  time vector for plots
mv2step        % simulate
%
% clear some memory
clear mag pha y1 y2 t
clear as bs cs ds al bl cl dl a b c d
clear a0 b0 c0 d0 dca dcb dcc dcd
pack
%
% Now repeat the process with the modified P+I compensator too
kdcnum=[1  0.5  0  0;0  0  1  0.5]; % polynomial num. matrix for compensator
kdcnum=diag([0.18  0.8])*kdcnum;  % multiply numerator matrix by gains
[dca,dcb,dcc,dcd]=mvtf2ss(kdcnum,kdccomden); % convert compensator to s.space
%
frk=mv2fr(dca,dcb,dcc,dcd,w);   % MVFR matrix of latest compensator
frl=fmulf(w,frm,frk);       % MVFR of overall-compensated system fwd. path
clm=feig(w,frl);            % calculate CLoci of overall-compensated system
%
plotbode(w,clm),title('C.L. after all comp.');pause
%
% clear some memory
clear clh clm
clear frh frk frl
clear mag pha y1 y2 t
pack
%
% Now build the state-space model for simulation:
[as,bs,cs,ds]=mvser([],[],[],kh,ap,bp,cp,dp); %cascade Kh with o/l plant
% swap for next 3 lines if i/ps are to be displayed (and alter 1 line below)
%ci=[cp;zeros(2,max(size(cp)))];
%di=[dp;eye(2)];
%[as,bs,cs,ds]=series([],[],[],kh,ap,bp,ci,di);
%
[am,bm,cm,dm]=mvser(ka,kb,kc,kd,as,bs,cs,ds); % Cascade ACC w. hf-comp. plant
[al,bl,cl,dl]=mvser(dca,dcb,dcc,dcd,am,bm,cm,dm);  % cascade dc comp.
[a,b,c,d]=mvfb(al,bl,cl,dl,[],[],[],eye(2));  % add UNF loops 
% use next line instead if i/ps were included using 3 lines above
%[a,b,c,d]=feedback(al,bl,cl,dl,[],[],[],eye(2),-[1  2],[1  2]);  % add UNF 
%
t=[0:0.06:6];  %  time vector for plots
mv2step        % simulate
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_20c
%
% matlab 3.5 print:
%meta fig10_20c
%!gpp fig10_20c /dhpgl /ol

