% Inverse Nyquist Array example just for Fig. 10.22
%

% Ken Dutton 1994
%
disp(' Entering model')
n11=5;
d11=[1  2  1/2];
n12=-2.5;
d12=[1  3  1];
n21=-7;
d21=[1  1  2];
n22=25;
d22=[1  5  2];
%
disp(' Rearranging to standard form')
%
%              (numerator polynomial matrix)
% form TFM as -------------------------------
%             (common denominator polynomial)
%
% form common denominator polynomial:
den=conv(d11,d12);
den=conv(den,d21);  
den=conv(den,d22);
%
% form terms of numerator polynomial matrix:
%
num11=conv(n11*d12,d21);
num11=conv(num11,d22);
num12=conv(n12*d11,d21);
num12=conv(num12,d22);   
num21=conv(n21*d11,d12);
num21=conv(num21,d22);
num22=conv(n22*d11,d12);
num22=conv(num22,d21);
%
% pad each to length of den term with leading zeros, and build
% into numerator polynomial matrix:
%
dl=length(den);
num=[zeros(1,dl-length(num11)) num11 zeros(1,dl-length(num12)) num12;
     zeros(1,dl-length(num21)) num21 zeros(1,dl-length(num22)) num22];
%
disp(' Obtaining state-space description')
[a,b,c,d]=mvtf2ss(num,den);
ap=a;   % [a,b,c,d] will be reused - save plant in [ap,bp,cp,dp] for future
bp=b;
cp=c;
dp=d;
%
disp(' Calculating MVFR matrix')
w=logspace(-3,2,300);
fr=mv2fr(num,den,w);     % calculate the MVFR matrix for the plant
%
disp(' Calculating INA')
ifr=finv(w,fr);     % find inverse of MVFR matrix components for INA
disp(' Compensator design for r2 = r2 - 0.37 * r1')
k1=[1  0;-0.37  1];
if1=fmul(w,k1,ifr); % Cascade with the plant - note order of
% multiplication is opposite to that expected due to use of inverses
disp(' Compensator design for r1 = r1 - 0.27 * r2')
k2=[1  -0.27;0  1];
if2=fmul(w,k2,if1);          % Cascade with the plant
disp(' Compensator design for r2 = r2 * 0.55')
k3=[1  0;0  0.55];
if3=fmul(w,k3,if2);          % Cascade with the plant
inap4(w,if3,4,-1,0.2,-0.2,1) % plot INA
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_22
%
% matlab 3.5 print:
%meta fig10_22
%!gpp fig10_22 /dhpgl /ol
%
