% File fig10_28.m - Produces Perron-Frobenius plot

% Ken Dutton 1994, 1995

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')

% enter TFM and form s-s model:
% enter original plant TFM elements
n11=1.02;
n12=-0.52;
n21=-0.54;
n22=1.04;
d11=[11.76 1];
d12=[10.1 1];
d21=[10.4 1];
d22=[2.6 1];
%
%              (numerator polynomial matrix)
% form TFM as -------------------------------
%             (common denominator polynomial)
%
comden=conv(conv(conv(d11,d12),d21),d22);
num11=1.02*conv(conv(d12,d21),d22);
num12=-0.52*conv(conv(d11,d21),d22);
num21=-0.54*conv(conv(d11,d12),d22);
num22=1.04*conv(conv(d11,d12),d21);
%
% build numerator matrix, padding each term with leading
% zeros to same length as comden:
%
num=[0 num11 0 num12;0 num21 0 num22];
%
% Get state-space equivalent. Note that this turns out to be 8th
% order (try typing ap). Doesn't matter here, because the model is
% very simple and well-behaved. In general, the model could be reduced
% to 4th order using the balreal command, for better numerical properties.
% The gramian produced by balreal shows that ap, bp and cp can be replaced
% by the balanced state-space realisation with states 5 to 8 removed. 
% Here, we continue to use the non-minimal realisation.
%
[ap,bp,cp,dp]=mvtf2ss(num,comden);
%
%form mvfr matrix
w=logspace(-2,2,100);
fr=mv2fr(ap,bp,cp,dp,w);
ifr=finv(w,fr);    % restore the plant's inverse MVFR matrix
%
% Now the calculations necessary to
% obtain the Perron-Frobenius data:
%
m=abs(ifr);          % gets magnitude of each element of MVFR matrix
omega=fdiag(w,fdiag(w,m));   % sets all off-diagonal terms at
                             % every freq. point to zero.
gamma=fmulf(w,finv(w,omega),m);  % form "normalised comparison
           % matrix" - inverses of diagonalised mvfr magnitude
           % matrices, premultiplying non-diagonalized,
           % non-inverted version. Result is as follows: If a
           % component matrix of m was [a  b;c  d], the corresponding
           % component matrix of gamma is [1  b/a; c/d  1].
pfe=fperron(w,gamma);     % obtain P-F eigenvalue. This is made up
                          % of the largest eigenvalue of each
                          % component matrix (magnitudes) of gamma.
plotdb(w,pfe);pause              % Bode magnitude plot of P-F eigenvalue
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_28
%
% matlab 3.5 print:
%meta fg10_28
%!gpp fg10_28 /dhpgl /ol
