% Fig10_8.m - checks simple diagonalising compensator results
% and generates open and closed loop responses.

% Ken Dutton 1994

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')

% enter original plant TFM elements
n11=1.02;
n12=-0.52;
n21=-0.54;
n22=1.04;
d11=[11.76 1];
d12=[10.1 1];
d21=[10.4 1];
d22=[2.6 1];
%
%              (numerator polynomial matrix)
% form TFM as -------------------------------
%             (common denominator polynomial)
%
comden=conv(conv(conv(d11,d12),d21),d22);
num11=1.02*conv(conv(d12,d21),d22);
num12=-0.52*conv(conv(d11,d21),d22);
num21=-0.54*conv(conv(d11,d12),d22);
num22=1.04*conv(conv(d11,d12),d21);
%
% build numerator matrix, padding each term with leading
% zeros to same length as comden:
%
num=[0 num11 0 num12;0 num21 0 num22];
%
% Get state-space equivalent. Note that this turns out to be 8th
% order (try typing a). Doesn't matter here, because the model is
% very simple and well-behaved. In general, the model could be reduced
% to 4th order using the balreal command, for better numerical properties.
% The gramian produced by balreal shows that ap, bp and cp can be replaced
% by the balanced state-space realisation with states 5 to 8 removed. 
% Here, we continue to use the non-minimal realisation.
%
[a,b,c,d]=mvtf2ss(num,comden);
%
%custom command for time responses
t=[0:0.1:60];
mv2step
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_8a
%
% matlab 3.5 print:
%meta fig10_8a
%!gpp fig10_8a /dhpgl /ol
%
% The next large block calculated, checked and simplified the plant
% inverse TFM for use as precompensator. The actual values are entered
% after this block. To run the block, remove the 'while 0' and 'end'
%
while 0
   %
   %form inverse TFM in polynomial form
   comdeni=conv(num11,num22)-conv(num12,num21);
   num11i=conv(comden,num22);
   num12i=-conv(comden,num12);
   num21i=-conv(comden,num21);
   num22i=conv(comden,num11);
   % 
   %premultiply plant by inverse
   compn11=conv(num11i,num11)+conv(num12i,num21);
   compn12=conv(num11i,num12)+conv(num12i,num22);
   compn21=conv(num21i,num11)+conv(num22i,num21);
   compn22=conv(num21i,num12)+conv(num22i,num22);
   compden=conv(comdeni,comden); 
   %
   %element step responses to check
   step(compn11,compden),grid,title('Diagonalised (1,1) response - should be 1')
   pause
   step(compn22,compden),grid,title('Diagonalised (2,2) response - should be 1')
   pause
   step(compn12,compden),grid,title('Diagonalised (1,2) response - should be 0')
   pause
   step(compn21,compden),grid,title('Diagonalised (2,1) response - should be 0')
   pause
   %
   %now remove common roots (known to be in elements 1, 4, 5 and 6 of roots):
   rts=roots(comdeni);
   fact=poly([rts(1)   rts(4:6)']);
   [comdeni,rden]=deconv(comdeni,fact);
   [num11i,rn11]=deconv(num11i,fact);
   [num12i,rn12]=deconv(num12i,fact);
   [num21i,rn21]=deconv(num21i,fact);
   [num22i,rn22]=deconv(num22i,fact);
   %
   %output remainders to check (remove comments from required ones):
   %rden
   %pause
   %rn11
   %pause
   %rn12
   %pause
   %rn21
   %pause
   %rn22
   %pause
   % scale to give familiar numbers at dc (no effect on response):
   scl=1.04/num11i(length(num11i));
   comdeni=comdeni*scl;
   num11i=num11i*scl;
   num12i=num12i*scl;
   num21i=num21i*scl;
   num22i=num22i*scl;
   %
   %premultiply plant by approximated inverse
   compn11=conv(num11i,num11)+conv(num12i,num21);
   compn12=conv(num11i,num12)+conv(num12i,num22);
   compn21=conv(num21i,num11)+conv(num22i,num21);
   compn22=conv(num21i,num12)+conv(num22i,num22);
   compden=conv(comdeni,comden);
   %
   % diagonalised element step responses to check
   step(compn11,compden),grid,title('Approx. Diag. (1,1) response - should be 1')
   pause
   step(compn22,compden),grid,title('Approx. Diag. (2,2) response - should be 1')
   pause
   step(compn12,compden),grid,title('Approx. Diag. (1,2) response - should be 0')
   pause
   step(compn21,compden),grid,title('Approx. Diag. (2,1) response - should be 0')
   pause
   comdeni
   num11i
   num12i
   num21i
   num22i
end
%
% Values of inverse plant TFM finally used in text book. Note
% that, at this point, numerator terms are one element LONGER
% than common denominator. This will be corrected when the
% dynamic compensator is added:
comdeni=[102.84  17.71  0.78];
num11i=[1284.7  360  33.6  1.04];
num12i=[165.4  93.6  12.9  0.52];
num21i=[166.8  94.8  13.2  0.54];
num22i=[278.6  161.5  23.6  1.02];
%
% Cascade with dynamic compensator part  = diag(1/(s(s+1))):
% Multiply common denom. by compensator denom.:
comden=conv(comdeni,[1  1  0]); % will now be 4th order, 5 terms
% Pad numerator terms (* unity from comp.) to new length (5 terms): 
num=[0 num11i 0 num12i; 0 num21i 0 num22i];
%
% state-space model of compensator:
[ak,bk,ck,dk]=mvtf2ss(num,comden);
%
% modify s-s model of plant to show inputs:
ap=a;
bp=b;
[rwc clc]=size(c);
cp=[c; zeros(2,clc)];
dp=[d; eye(2)];
%
% cascade with compensator and add UNF
[ao,bo,co,do]=series(ak,bk,ck,dk,ap,bp,cp,dp);
[a,b,c,d]=feedback(ao,bo,co,do,[],[],[],eye(2),-[1  2],[1  2]);
t=[0:0.1:40];
mv2step
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_8b
%
% matlab 3.5 print:
%meta fig10_8b
%!gpp fig10_8b /dhpgl /ol
