function [ret,x0,str,ts,xts]=fig11_11(t,x,u,flag);
%FIG11_11	is the M-file description of the SIMULINK system named FIG11_11.
%	The block-diagram can be displayed by typing: FIG11_11.
%
%	SYS=FIG11_11(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes FIG11_11 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling FIG11_11 with a FLAG of zero:
%	[SIZES]=FIG11_11([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[29,197,478,460])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '20')
set_param(sys,'Min step size', '.02')
set_param(sys,'Max step size', '.02')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','2.000000',...
		'Hgain','0.010000',...
		'Vmax','4.000000',...
		'Hmax','0.020000',...
		'Window',[112,160,443,474],...
		'position',[335,40,365,70])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn1'])
set_param([sys,'/','Transfer Fcn1'],...
		'Numerator','[2]',...
		'Denominator','[1 10]',...
		'position',[165,172,200,208])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'Numerator','40',...
		'Denominator','[1 10 20]',...
		'position',[185,40,260,80])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'inputs','+-',...
		'position',[110,50,130,70])


%     Subsystem  ['Pulse',13,'Generator'].

new_system([sys,'/',['Pulse',13,'Generator']])
set_param([sys,'/',['Pulse',13,'Generator']],'Location',[272,165,909,406])

add_block('built-in/Unit Delay',[sys,'/',['Pulse',13,'Generator/Unit Delay1']])
set_param([sys,'/',['Pulse',13,'Generator/Unit Delay1']],...
		'orientation',2,...
		'Sample time','[Ts/2,st2]',...
		'x0','ini',...
		'position',[140,165,190,185])

add_block('built-in/Unit Delay',[sys,'/',['Pulse',13,'Generator/Unit Delay']])
set_param([sys,'/',['Pulse',13,'Generator/Unit Delay']],...
		'orientation',2,...
		'Sample time','[Ts/2,st1]',...
		'position',[145,75,195,95])

add_block('built-in/Gain',[sys,'/',['Pulse',13,'Generator/Gain1']])
set_param([sys,'/',['Pulse',13,'Generator/Gain1']],...
		'Gain','g',...
		'position',[235,122,255,138])

add_block('built-in/Constant',[sys,'/',['Pulse',13,'Generator/Constant']])
set_param([sys,'/',['Pulse',13,'Generator/Constant']],...
		'position',[25,30,45,50])

add_block('built-in/Saturation',[sys,'/',['Pulse',13,'Generator/Saturation']])
set_param([sys,'/',['Pulse',13,'Generator/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','1',...
		'position',[365,40,390,60])

add_block('built-in/Sum',[sys,'/',['Pulse',13,'Generator/Sum2']])
set_param([sys,'/',['Pulse',13,'Generator/Sum2']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[300,40,320,60])

add_block('built-in/Sum',[sys,'/',['Pulse',13,'Generator/Sum']])
set_param([sys,'/',['Pulse',13,'Generator/Sum']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[135,35,155,55])

add_block('built-in/Sum',[sys,'/',['Pulse',13,'Generator/Sum1']])
set_param([sys,'/',['Pulse',13,'Generator/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[130,120,150,140])

add_block('built-in/Relational Operator',[sys,'/',['Pulse',13,'Generator/Relational',13,'operator']])
set_param([sys,'/',['Pulse',13,'Generator/Relational',13,'operator']],...
		'hide name',0,...
		'position',[370,102,400,133])

add_block('built-in/Gain',[sys,'/',['Pulse',13,'Generator/Gain']])
set_param([sys,'/',['Pulse',13,'Generator/Gain']],...
		'hide name',0,...
		'Gain','ht',...
		'position',[540,102,565,128])

add_block('built-in/Product',[sys,'/',['Pulse',13,'Generator/Product']])
set_param([sys,'/',['Pulse',13,'Generator/Product']],...
		'hide name',0,...
		'position',[470,105,495,125])

add_block('built-in/Clock',[sys,'/',['Pulse',13,'Generator/Clock1']])
set_param([sys,'/',['Pulse',13,'Generator/Clock1']],...
		'hide name',0,...
		'position',[295,100,315,120])

add_block('built-in/Constant',[sys,'/',['Pulse',13,'Generator/Constant1']])
set_param([sys,'/',['Pulse',13,'Generator/Constant1']],...
		'Value','stt',...
		'position',[295,149,320,171])

add_block('built-in/Outport',[sys,'/',['Pulse',13,'Generator/out_1']])
set_param([sys,'/',['Pulse',13,'Generator/out_1']],...
		'hide name',0,...
		'position',[590,105,610,125])
add_line([sys,'/',['Pulse',13,'Generator']],[260,130;275,130;275,55;295,55])
add_line([sys,'/',['Pulse',13,'Generator']],[155,130;230,130])
add_line([sys,'/',['Pulse',13,'Generator']],[325,50;360,50])
add_line([sys,'/',['Pulse',13,'Generator']],[160,45;295,45])
add_line([sys,'/',['Pulse',13,'Generator']],[50,40;70,40;70,125;125,125])
add_line([sys,'/',['Pulse',13,'Generator']],[135,175;100,175;100,135;125,135])
add_line([sys,'/',['Pulse',13,'Generator']],[155,130;210,130;210,175;195,175])
add_line([sys,'/',['Pulse',13,'Generator']],[50,40;130,40])
add_line([sys,'/',['Pulse',13,'Generator']],[160,45;230,45;230,85;200,85])
add_line([sys,'/',['Pulse',13,'Generator']],[140,85;105,85;105,50;130,50])
add_line([sys,'/',['Pulse',13,'Generator']],[320,110;365,110])
add_line([sys,'/',['Pulse',13,'Generator']],[405,120;465,120])
add_line([sys,'/',['Pulse',13,'Generator']],[500,115;535,115])
add_line([sys,'/',['Pulse',13,'Generator']],[570,115;585,115])
add_line([sys,'/',['Pulse',13,'Generator']],[325,160;345,160;345,125;365,125])
add_line([sys,'/',['Pulse',13,'Generator']],[395,50;430,50;430,110;465,110])
set_param([sys,'/',['Pulse',13,'Generator']],...
		'Mask Display','plot(0,0,100,100,[90,75,75,60,60,35,35,20,20,10],[20,20,80,80,20,20,80,80,20,20])',...
		'Mask Type','Pulse Generator')
set_param([sys,'/',['Pulse',13,'Generator']],...
		'Mask Dialogue','Pulse Generator.|Pulse period (secs):|Pulse width:|Pulse height:|Pulse start time:')
set_param([sys,'/',['Pulse',13,'Generator']],...
		'Mask Translate','Ts=@1; du=@2; ht=@3; stt=@4; g=1; ini=ones(length(@3),1); if (Ts<2*du), g=-1; du=du-Ts/2; ini=zeros(length(@3),1); end; st1=rem(stt,Ts); st2=rem(stt+du,Ts);')
set_param([sys,'/',['Pulse',13,'Generator']],...
		'Mask Help','Pulse generator which ensures pulse\ntransitions are hit. Provides a vector of pulses when the height is entered as a vector.\nUnmask to see how it works.')
set_param([sys,'/',['Pulse',13,'Generator']],...
		'Mask Entries','4\/2\/1\/0.5\/')


%     Finished composite block ['Pulse',13,'Generator'].

set_param([sys,'/',['Pulse',13,'Generator']],...
		'position',[30,47,65,83])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','20\/-.5\/2.5\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'position',[335,106,365,144])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','bill',...
		'position',[385,87,435,103])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'orientation',2,...
		'Gain','100',...
		'position',[100,116,155,144])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'orientation',2,...
		'inputs','-+',...
		'position',[210,120,230,140])
add_line(sys,[135,60;180,60])
add_line(sys,[265,60;290,60;290,55;330,55])
add_line(sys,[70,65;80,65;80,55;105,55])
add_line(sys,[95,130;105,65])
add_line(sys,[205,130;160,130])
add_line(sys,[205,190;245,190;235,125])
add_line(sys,[290,55;290,135;235,135])
add_line(sys,[80,65;80,190;160,190])
add_line(sys,[315,55;315,125;330,125])
add_line(sys,[315,95;380,95])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
