% Fig11_7.m  Self-tuning controller simulation.
% Identical to  fig11_6.m except for the addition of the
% controller synthesiser.

% The comments in  fig11_4.m  should be read to understand the code.
% New material is marked %**************************

% Ken Dutton & Bill Barraclough, 1996

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')
disp(' The calculations may take a while')
disp(' ')
disp(' Press any key after viewing these messages')
pause 

disp(' ')
disp('The mass m will be 1.0 kg initially.')
disp('It will increase to 5 kg after 20 s')
disp('and reduce to 0.2 kg after 40 s.')
disp(' ')

%*****************************
% acquire the desired forgetting factor:
disp(' ')
ff=input(' Input the forgetting factor, recommended values 0.9 to 1.0 ');
if isempty(ff), ff=1.1;end  % allows the following 'if' statement to work
if ff>1
   disp(' Forgetting factor internally set to 1')
   ff=1;
elseif ff<0.5
   disp(' Forgetting factor is not allowed be less than 0.5 - is reset to 0.9')
   ff=0.9;
end

% select self-tuning or not?
disp(' ')
disp(' Press return to enable self-tuning');
stg=input(' or enter a number to disable it ');
if isempty(stg)
   stg=1;
   disp('Self-tuning enabled')
else
   stg=0;
   disp('Self-tuning disabled')
end
%******************************

num=40;
den=[1 10 20];
ts=0.05;  
[bp,ap]=c2dm(num,den,ts);
ap=-ap(2:length(ap));
bp=bp(2:length(bp));  
q=length(bp);
p=length(ap);
da=[1 0];
db=0.1*[1 -ap]/sum(bp);
pcvm=eye(p+q)*1000;
theta=ones(p+q,1);
shift=[0 0 0 0
       1 0 0 0
       0 0 0 0
       0 0 1 0];
t20=round(20/ts);
t40=round(40/ts);
if t20 > 400
   t20=400;
   t40=800;
end
isteps=3*t20;
t=[1 : isteps]*ts;
y=0;
ev=[0 0]';     % vector of past errors
x=[0 0 0 0]';  % vector of past outputs stacked above vector of past inputs

nn=menu('Choose an input signal:','low-frequency square wave',...
                                  'single step','sinewave');
w=2*pi*0.1;  % radian frequency for 0.1 Hz
if nn==1, r=square(w*t);end        % data points for squarewave input
if nn==2, r=ones(1,isteps);end     % data points for single step input
if nn==3, r=sin(w*t);end           % data points for sinewave input


disp(' ')
disp(' Calculating responses - please wait')
disp(' ')
pause(1)

for i1=1:isteps
	if i1==t20 
		m=5;
		den=[m 10 20];
		[bp,ap]=c2dm(num,den,ts);
		ap=-ap(2:length(ap));
                bp=bp(2:length(bp)); 
	end
	if i1==t40 
		m=0.2;
		den=[m 10 20];
		[bp,ap]=c2dm(num,den,ts);
		ap=-ap(2:length(ap));
                bp=bp(2:length(bp));
	end


	e = r(i1)-x(1);              % loop error
	u = da*x(3:4) + db*[e; ev];  % digital controller
	y=ap*x(1:2) + bp*x(3:4); % plant
        ev(2)=ev(1);
	ev(1)=e;
	uu(i1)=u; 
	yy(i1)=y;  

	a1(i1)=theta(1); % store last identified coefficients for plotting
	a2(i1)=theta(2);
	b1(i1)=theta(3);
	b2(i1)=theta(4);
	temp=x'*pcvm;
	temp1=1 + temp*x;
        temp2=x'*theta - y;
	if temp1~=0
           temp3=pcvm*x*temp2/temp1;
           theta=theta-temp3;          % parameter estimate update
           temp4=x*x';
           temp5=pcvm*temp4;
           temp6=temp5*pcvm/temp1;
	   pcvm=pcvm-temp6;            % covariance update
%*******************
           pcvm=pcvm/ff;               % forgetting factor
%*******************
        end

	x=shift*x;       % update vector of past outputs over inputs
	x(1)=y;
	x(3)=u;

%*********************** differs from here to the end ************8     

        if stg==1
           % controller synthesiser
           kk=sum(theta(3:4))/sum([1  -theta(1:2)']); % d.c. gain
           if kk>0 & kk<10  % safety limits on d.c. gain
              % now re-tune the controller:
              % da stays the same, but db must change:
	      db=0.1*[1  -theta(1:2)']/sum(theta(3:4));
           end
        end
end

subplot 311
plot(t,r),grid
axis([0 60 -2 2]);
subplot 312
plot(t,uu),grid
axis([0 60 -2 2]);
subplot 313
plot(t,yy),grid
axis([0 60 -2 2]);
subplot 111
