% fig12_14.m - Designs optimal controller for tool-positioner

% Ken Dutton, 1993

% State-space model of plant:
disp('')
disp('Creating state-space model')
a=[0  1; 0  -10];    b=[0  0.5]';   c=[1  0];   d=0;
% weighting quantities:
disp('Designing LQR')
r=0.001              %single-input weighting (orig 1)
q=diag([600  2]);    % guess at state weightings
titl=['State responses'];
%optimal design:
[k,p,e]=lqr(a,b,q,r);
% closed-loop eigenvalues
disp('')
disp('Closed-loop poles:')
e
disp(' ')
disp('Press any key to continue')
pause
%
% At present, we have states x1 and x2, and the single
% output y1.  So c is 1*2, and d scalar.
% Add states x1 and x2 as outputs y2 and y3, ready to be
% fed back and plotted:
[ap,bp,cp,dp]=augstate(a,b,c,d);
%
% Now cp will be 3*2, and dp will be 3*1.
% Next, add the input as a further output (y4) for plotting:
disp('')
disp('c and d matrices with y1,2,3,4 = y,x1,x2,u:')
cpi=[cp; 0  0]		% now 4*2 - listed to check
dpi=[dp;  1]		% now 4*1 - listed to check
disp('Press any key to continue')
pause
disp('')
disp('Building tracking system and simulating')
%
% Connect SVF matrix, k, in the FORWARD path, so that the reference
% inputs are applied directly to the states at y2 and y3, giving a
% TRACKING SYSTEM:
% Put SVF gain IN FRONT of plant to make forward path:
[af,bf,cf,df]=series([],[],[],k,ap,bp,cp,dp);
%
% add UNF from y2(=x1) to r1 and y3(=x2) to r2, so that
% the reference signals are added at the plant OUTPUTS:
[ac,bc,cc,dc]=feedback(af,bf,cf,df,[],[],[],eye(2),-[1  2],[2  3]);
%
% We always want x2 (velocity) to go to zero at steady state. 
% Hence, just apply step to r1:
t=[0:0.004:0.4];
disp('')
disp('Plotting now - press a key after viewing plot')
subplot(221)
step(ac,bc,cc,dc,1,t),title(titl),grid 
%
% now repeat with input displayed:
%
% Connect SVF matrix, k, in the FORWARD path, so that the reference
% inputs are applied directly to the states at y2 and y3, giving a
% TRACKING SYSTEM:
[af,bf,cf,df]=series([],[],[],k,ap,bp,cpi,dpi);	 % makes fwd path
%
% add UNF from y2 to r1 and y3 to r2:
[ac,bc,cc,dc]=feedback(af,bf,cf,df,[],[],[],eye(2),-[1  2],[2  3]);
titli='Figure 12.14(a) plus control input';
subplot(222)
step(ac,bc,cc,dc,1,t),title(titli),grid 
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig12_14
%
% matlab 3.5 print:
%meta fig12_14
%!gpp fig12_14 /dhpgl /ol
pause
clg
%
% separate plot of o/p to allow measurement of rise-time:
t=[0:0.005:0.5];
[yy,xx]=step(ac,bc,cc,dc,1,t);
plot(t,yy(:,1)),ylabel('Amplitude'),xlabel('Time (secs)'),...
                title(titl),grid
disp('')
disp('Position cursor on 10% level, press LH mouse button.')
disp('Repeat for 90% level.')
disp('Press return after reading this message,')
disp('and again after clicking on the two levels')
% use cursor to pick off 10% and 90% times:
pause
[xxx,yyy]=ginput;
disp('')
disp('Rise time is:')
tr=xxx(2)-xxx(1)
clg
