% fig14_19.m - PPT for discontinuous example in fig. 14.18
%
% N/L is deadzone of +/- dz, with slope 1, at o/p of system
% Linear part is 16/(s^2 + 4s +8)
% Input is unit step
%
% See fig14_17.m for more detailed comments

% Ken Dutton, 1994

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')

%
% Use disc. time s-s model, with x1 = y as o/p
%
disp('')
disp('Calculating phase plane trajectories and simulating')
disp('Please wait for plots - press return to see second one')
dz=0.8;                  % half of total deadzone width
a=[0  1;-8  -4]; b=[0  16]'; ts=0.01;
[phi,del]=c2d(a,b,ts);
xnl=[0  0]';             % to hold nonlinear state responses
xnlold=xnl;
xlin=[0  0]';            % to hold linear state responses
xlinold=xlin;
linop=0;                 % y and dy/dt for o/p PPTs if needed
linopdot=0;
nlop=0;
nlopdot=0;
t=0;
u=1;
tend=4;
while t<tend
   t=[t  t(length(t))+ts];
   elin=u-linop(length(linop));       % linear error
   xlinold=phi*xlinold+del*elin;      % advance linear responses
   linop=[linop   xlinold(1)];        % new lin o/p
   % and dx1/dt = dy/dt = [(present o/p) - (last o/p)]/(time step):
   linopdot=[linopdot    (xlinold(1)-linop(length(linop)-1))/ts];
   xlin=[xlin  xlinold];              % add new values to responses
   enl=u-nlop(length(nlop));          % nonlinear error
   xnlold=phi*xnlold+del*enl;         % advance nonlinear responses
   xnl=[xnl  xnlold];                 % add new values to responses
   if xnlold(1)>=-dz & xnlold(1)<=dz     % deadzone element
      nlopp=0;
   elseif xnlold(1)>dz
      nlopp=xnlold(1)-dz;
   else
      nlopp=xnlold(1)+dz;
   end
   nlop=[nlop  nlopp];                % new nonlinear o/p
   % and d/dt of output (see linopdot above):
   nlopdot=[nlopdot    (nlopp-nlop(length(nlop)-1))/ts];
end
disp('')
disp('Plotting now - press any key after viewing plots')
axis([0 2 -1 4]);
plot(xnl(1,:),xnl(2,:)),grid,hold on; %  PPT at plant o/p (before d/zone)
%plot(xlin(1,:),xlin(2,:));            % lin. PPT
axis([0 2 -1 4]);
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig14_19a
%
% matlab 3.5 print:
%meta f14_19a
%!gpp f14_19a /dhpgl /ol
hold off
axis('normal');
n=fix(length(t)*.75);    % only plot as many points as needed (75%)
plot(t(1:n),xnl(1,(1:n)))    % n/l plant o/p
hold on
plot(t(1:n),xlin(1,(1:n)),'g'),grid  % lin plant o/p 
plot(t(1:n),nlop(1:n))               % n/l overall o/p
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig14_19b
%
% matlab 3.5 print:
%meta f14_19b
%!gpp f14_19b /dhpgl /ol
hold off
clg