% fig14_26.m
% PPT for relay example in fig. 14.25
%
% N/L is ideal relay, but with rate feedback control
% Linear part is 3/(s(1+2s))
% Input is step

% Ken Dutton, 1994

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')

% Use disc. time s-s model, with x1 as o/p1 and dx1/dt=x2 as o/p2
%
% NB very short ts needed for instantaneous relay. Misleading if not.
% see comments at end for handling data.
%
% Plots in book were for ts=0.005 over 6.5sec for k=1/3
%

k=1/3;       % rate feedback gain (gives switching line slope -1/k)
a=[0  1;0  -1/2]; b=[0  3/2]'; ts=.005;
[phi,del]=c2d(a,b,ts);
tend=6.5;
points=(tend/ts)+1;
t=zeros(1,points);
xnl=zeros(2,points);
xnl(:,1)=[0   0]'; % initial nonlinear state responses
xnlold=xnl(:,1);
u=4;             % step input
e=zeros(size(t));
edot=zeros(size(t));
e(1)=u-xnlold(1);   % initial error
edot(1)=-xnlold(2); % and initial derivative
ndisp=0;
for i=1:points
   if ndisp==0
      disp(['Reached '  num2str(i)  ', aiming at '  num2str(points)])
   end
   ndisp=ndisp+1;
   if ndisp==100, ndisp=0; end
   enl=u-xnlold(1);                  % nonlinear error
   relinp=enl-k*xnlold(2);           % relay input
   if i>1  % skip first time (deriv. calc. impossible - first values
           %                                              inserted above).
      t(i)=t(i-1)+ts;
      e(i)=enl;
      edot(i)=(e(i)-e(i-1))/ts;
   end;
   if relinp>=0            % relay
      ENL=1;
   else
      ENL=-1;
   end
   xnlold=phi*xnlold+del*ENL;     % advance nonlinear responses
   xnl(:,i)=xnlold;
end
%
%
% invoke next block of code if very large data files are in use,
% then run fdatprc to process them (more necessary for v3.5 than v4.2).
% Otherwise, use code block at the end to plot directly from this m-file
%
while 0  % comment-out this 'while' and 'end' to store data to floppy
   !erase fdatprc.mat
   save fdatprc xnl e edot t
   disp('')
   disp('')
   disp('Put a formatted floppy disk in drive a:')
   disp('')
   disp('The file fdatprc.mat will be copied to this disk and ')
   disp('then erased from the hard disk.')
   disp('')
   disp('Press any key when the disk is ready in drive a:')
   pause
   !copy fdatprc.mat a:
   !erase fdatprc.mat
   disp('')
   disp('type  fdatprc  at the MATLAB prompt to process the floppy')
   disp('disk and produce hpgl plot files.')
   disp('')
   disp('Press any key after noting this message')
   pause
end
%
% invoke the remainder for shorter data files (or MATLAB v4.2)
%while 0   % comment out this 'while' and 'end' to plot directly
   disp('')
   disp('Producing plot - press any key after viewing plots')
   subplot(211)  % plot in upper half of screen
   plot(e,edot),grid,title('e vs edot')
   subplot(212)  % plot in lower half of screen
   plot(t,xnl(1,:)),grid,title('x1 vs time')
   pause
   %
   % matlab 4.2 print:
   %orient landscape
   %print -dhpgl fig14_26
   %
   % matlab 3.5 print:
   %meta fig14_26
   %!gpp fig14_26 /dhpgl /ol
%end 
hold off
clg
