% fig14_36.m - Decscribing Function analysis for Fig14.36
%
% also simulates the system - not in the text

% Ken Dutton, 1994

disp(' ')
disp(' Ignore ''warning'' messages')
disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key to continue after viewing a plot')
disp(' ')
disp(' Press any key after noting these messages')
disp(' ')
pause

%
% linear part of system:
%
num=50;
den=conv([1  5  0],[1  1]);
%
% nonlinear part describing function (positive for now):
em=[2:0.3:200];   % set of values of em at which to evaluate df
n=0.5 + pi^(-1)*(asin(2*em.^(-1)) + 2.*em.^(-1).*sqrt(1-4*em.^(-1).*em.^(-1)));
%
% inverse nyquist of linear part:
w=logspace(-3,1,500);
w=w(1:435);
[re,im]=nyquist(num,den,w);    % direct nyquist data (real + imag)
invden=re.*re + im.*im;   % form the denominator for inverse plot
invre=re.*invden.^(-1);   % real parts for inverse nyquist
invim=-im.*invden.^(-1);  % imag parts for inverse nyquist
disp('')
disp('Plotting now')
plot(invre,invim),grid    % produce inverse nyquist graph
hold on
plot(-n,zeros(n))         % add the DF plot
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig14_36
%
% matlab 3.5 print:
%meta fig14_36
%!gpp fig14_36 /dhpgl /ol
hold off
%
% detect if MATLAB for Windows is being used. If so, close
% the figure window to make the progress count visible:
%
v=version;      % detect MATLAB version ('3.5k', '4.2b', etc)
v=v(1);         % typically '3' or '4' (string) at time of writing
if v>='4'       % v is never used again after this - remainder
                % of file common to both versions
  close all;    % MATLAB version 4 (or higher) forced to close plot window
end

%
%
% simulation to confirm the limit cycle (not in text):
[a,b,c,d]=tf2ss(num,den); % state-space model of linear part
ts=0.006;                 % sample interval
[phi,del]=c2d(a,b,ts);    % discrete-time state-space model
tend=16;                  % end time for simulation
points=tend/ts;           % number of data points
yold=14;   % initial conditions on the output
           % (x3 is set to 1/50th of this, below)
ystor=zeros(1,points+1);  % initialise vector to hold o/p values 
ystor(1)=yold;
xold=[0  0  yold/50]';    % initial state values to start the simulation
t=zeros(ystor);           % initialise time vector to zero
%
ndisp=0;                  % user progress-display counter
disp('')
disp('Simulating - press any key after viewing plots')
for i = 1:points+1
   if ndisp==0            % user progress-display
      disp(['Reached '  num2str(i)  ', aiming at '  num2str(points+1)])
   end
   ndisp=ndisp+1;
   if ndisp==100, ndisp=0; end % reset progress display every 100 points
   t(i+1)=t(i)+ts;        % next time value
   error=-yold;           % error in feedback loop (zero ref. i/p)
   if abs(error) <= 2
      u=error;            % in mid-part of N/L characteristic
   else
      u=sign(error) * (2 + 0.5*(abs(error)-2)); % in saturated part
   end
   xnew=phi*xold+del*u;   % propagate states using discrete time model
   yold=c*xnew + d*u;     % new output value  
   ystor(i+1)=yold;       % add new values to output matrix for plotting
   xold=xnew;             % update the state vector for the next time step
end
%
plot(t,ystor),grid  % plot outputs vs. t
pause
hold off
clg
