% Plots step responses  for a second order system (Fig. 3.19)
% with k = 1, wn=1 and a preset range of values of zeta
%
% To plot Fig. 3.19(b), delete (or comment-out with % signs)
% the   while 0  and  end  statements marked  %1111111111111111111111

%
% Ken Dutton, 1993, 1995

disp(' ')
disp(' ')
disp('Calculating step responses - please wait')
disp(' ')

% standard undamped natural frequency and d.c. gain:
wn=1;
k=1;

% values of damping ratio to be used:
zeta=[0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 1 1.5 2];

% time axis for plots:
t=[0:0.025:16];

% LTF numerator:
num=k*wn^2;

%
% step response data:
yplt=[];  % empty matrix to hold results

for i=1:length(zeta)   % step through damping ratios
   den=[1 2*zeta(i)*wn wn^2]; % LTF denominator
   [y,x]=step(num,den,t);     % step response data (no plot yet)
   yplt=[yplt y];             % store for plotting
end

%
% step response plots:
plot(t,yplt,'w'),grid;

%
% add extra vertical grid lines:
hold on            % freeze plot on screen
xplt=[];           % empty array to hold grid lines
y=[0:1.8/31:1.8]'; % set of y values for grid lines

for i=0:0.5:16
   xplt=[xplt  ones(length(y),1)*i];
end
plot(xplt,y,'w--')

%
% similarly add extra horizontal grid lines:
yplt=[];
x=[0:15/18:16]';
for i=0:0.1:1.7
   yplt=[yplt ones(length(x),1)*i];
end
plot(x,yplt,'w--')

hold off  % release plot window


while 0  %1111111111111(see matching  'end'  below)1111111111111111111
%
% damping ratio graph and table values:

zeta=[0:0.01:1];
wtpk=pi./sqrt(1-zeta.^2); % time to peak, times w to normalise
mpk=100*exp(-zeta.*wtpk); % per cent overshoot
plot(zeta,mpk,'w');grid
hold on  % freeze plot on screen
%
% scale wtpk values such that w.tpk=3.0 coincides with zero on the
% percent overshoot axis already plotted, and 5.5 with 100:
wtpk=(wtpk-3)*40;
% clamp any resulting values in excess of 100, to 100:
index=find(wtpk>100);
wtpk(index)=100*ones(size(index));
plot(zeta,wtpk,'w')

%
% add extra vertical grid lines:
hold on
x=[];
y=[0:100/21:100]';
for i=0:0.05:1
   x=[x  ones(length(y),1)*i];
end
plot(x,y,'w--')

%
% add extra horizontal grid lines:
y=[];
x=[0:1/11:1]';
for i=0:10:100
   y=[y ones(length(x),1)*i];
end
plot(x,y,'w--')

hold off  % release plot window

end %11111111111111111111(see matching  'while'  above)11111111111




disp(' ')
disp('The data and plot will be occupying a lot of memory.')
disp('It is recommended that you clear the memory and')
disp('the plot before doing anything else.')
disp(' ')
disp('The commands   clear   and   close   will do this')
disp('in newer MATLABs.  Use   help clear   otherwise.')
disp(' ')
disp('Type   help fig3_19  to find out about Fig. 3.19(b)')
disp(' ')
disp('Press a key to continue after noting the message above')
pause

