% Plots frequency responses  for a second order system (Fig. 3.39)
% with k = 1, wn=1 and a preset range of values of zeta
%
% To plot phases, Fig. 3.39(b), delete (or comment-out with % signs)
% the   while 0  and  end  statements marked  %1111111111111111111111

%
% Ken Dutton, 1993, 1995



% standard undamped natural frequency and d.c. gain:
wn=1;
k=1;

% LTF numerator:
num=k*wn^2;

disp(' ')
disp('Calculating frequency response magnitudes')
disp('Please wait')
disp(' ')

% set of damping ratios to be used:
zeta=[0.1 0.15 0.2 0.25 0.3 0.35 0.4 0.45 0.5 0.6 0.7 0.8 0.9 1];


% frequency values:
w=logspace(-1,1,300);
w=w(1:215); %restricted range for better plot
% use the axis command for more selective results

yplt=[];                      % empty array to hold responses
for i=1:length(zeta)          % step through zeta values
   den=[1 2*zeta(i)*wn wn^2]; % denominator of LTF
   [mag,pha]=bode(num,den,w); % magnitude and phase data (no plot yet)
   yplt=[yplt 20*log10(mag)]; % store magnitude in dB for plotting
end

%
% magnitude response plot:
semilogx(w,yplt,'w');grid;
%axis([0.1 3 -15 15]);

%
% add extra horizontal grid lines:
hold on  % freeze plot on screen
yplt=[];
x=[0.1:0.01:0.5  0.52:0.02:1  1.1:0.1:3];
for i=-15:15
    yplt=[yplt ones(length(x),1)*i];
end
plot(x,yplt,'w--')

%
% add extra vertical grid lines:
y=[-15:15/(length(x)-1):15];
xplt=[];
for i=1:length(x)
   xplt=[xplt  ones(length(y),1)*x(i)];
end
plot(xplt,y,'w--')

%
% add -40dB / decade line (as -12dB / octave)
plot([1  2.5],[0  -15]);

hold off %(release plot window

%
while 0 %111111111111111111(see matching  'end'  below)111111111111111111111

disp('Calculating frequency response phases')
disp('Please wait')
disp(' ')

% comments as above

zeta=[0.1 0.15 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1];
w=logspace(-1,1,200);
yplt=[];
for i=1:length(zeta)
   den=[1 2*zeta(i)*wn wn^2];
   [mag,pha]=bode(num,den,w);
   yplt=[yplt pha];
end

%
% phase response plot:
semilogx(w,yplt,'w');grid;
axis([0.1 10 -180 0]);

%
% add extra horizontal grid lines:
hold on
yplt=[];
x=[0.1:0.01:0.5  0.52:0.02:1  1.1:0.1:5  5.2:0.2:10];
for i=-180:5:0
    yplt=[yplt ones(length(x),1)*i];
end
plot(x,yplt,'w--')

%
% add extra vertical grid lines:
y=[-180:180/(length(x)-1):0];
xplt=[];
for i=1:length(x)
   xplt=[xplt  ones(length(y),1)*x(i)];
end
plot(xplt,y,'w--')

hold off % release plot window

end %111111111111111111111111(see matching  'while'  above)1111111111111111111


disp(' ')
disp('The data and plot will be occupying a lot of memory.')
disp('It is recommended that you clear the memory and')
disp('the plot before doing anything else.')
disp(' ')
disp('The commands   clear   and   close   will do this')
disp('in newer MATLABs.  Use   help clear   otherwise.')
disp(' ')
disp('Type   help fig3_39  to find out about')
disp('the phase responses in Fig. 3.39(b)')
disp(' ')
disp('Press a key to continue after noting the message above')
pause

