% Numerical solution (Euler) of Eq. [5.21]
% Generates Fig. 5.10
%

% Bill Barraclough 1994
% Ken Dutton 1996

clear y t   % ensure no previous results

% initialise

ts=0.05; % change this value for different
         % integration period

y(1)=0;
t(1)=0;
lasty=0;
u=1;     % this will do for a unit step - permanently=1
tmax=2;  % 2 second simulation

for n=2:tmax/ts+1           % iteration begins here
        t(n)=t(n-1)+ts;     % time value for this step
	ydot=10*u-2*lasty;  % evaluate derivative
	y(n)=lasty+ts*ydot; % new output
	lasty=y(n);         % update
end

plot(t,y),grid

% add 'actual' plot for comparison
hold on          % freeze plot in window
ta=[0:0.1:2];
[ya,xa]=step(5,[0.5  1],ta);
plot(ta,ya)
hold off         % release plot window


disp(' ')
disp(' The plot is for Ts=0.05')
disp(' (Lower curve is ''actual'' plot)')
disp(' Edit the file for different values')
disp(' ') 