% Numerical solution (Runge-Kutta) of Eq. [5.21]
% Generates Fig. 5.12
%

% Bill Barraclough 1994
% Ken Dutton 1996

clear y t   % ensure no previous results

% initialise
ts=0.2;  % change this value for different
         % integration period
y(1)=0;
t(1)=0;
lasty=0;
u=1;     % this will do for a unit step - permanently=1
tmax=2;  % 2 second simulation

for n=2:tmax/ts+1           % iteration begins here
        t(n)=t(n-1)+ts;        % next time value
	ydot=10*u-2*lasty;     % first derivative calculation
	k1=ts*ydot;            % first prediction
	ymid=lasty+ts/2*ydot;  % etc. as per text
	ydot=10*u-2*ymid;
	k2=ts*ydot;
	ymid=lasty+ts/2*ydot;
	ydot=10*u-2*ymid;
	k3=ts*ydot;
	yend=lasty+ts*ydot;
	ydot=10*u-2*yend;
	k4=ts*ydot;
	y(n)=lasty + (k1+2*k2+2*k3+k4)/6;  % output
	lasty=y(n);                        % update
end

plot(t,y),grid

% add 'actual' plot for comparison
hold on          % freeze plot in window
ta=[0:0.1:2];
[ya,xa]=step(5,[0.5  1],ta);
plot(ta,ya)
hold off         % release plot window


disp(' ')
disp(' The plot is for Ts=0.2')
disp(' (Smoother curve is ''actual'' plot)')
disp(' Edit the file for different values')
disp(' ')


