% Digital controller implementation for Example 5.11
% Generates Fig. 5.19
%

% Bill Barraclough 1994
% Ken Dutton 1996

% To experiment with the different controllers, 
% edit  numdc  and  dendc  below

% initialise
ts=0.1;   % change this value for different integration period
tmax=6;  % 6 second simulation duration

% set up an axis of time points (only for use on plot axis):
t=[0:ts:tmax];
% find number of simulation steps:
nmax=length(t);

% s-domain plant transfer function:
nump=10;
denp=[1  7  6  0];

% convert to discrete-time model to allow simulation with discrete
% controller (for mixed discrete control + continuous plant
% try SIMULINK instead).
[numdp,dendp]=c2dm(nump,denp,ts,'zoh');


% z-domain controller transfer function
% remove comment marks from the one to try only

% this one is 'simple method':
numdc=[1.2692  -1.1538];
dendc=[1  -0.7692];

% this one is Tustin method:
%numdc=[1.3696  -1.2391];
%dendc=[1  -0.7391];

% this one is matched p-z:
%numdc=[1.3618  -1.2322];
%dendc=[1  -0.74082];

% form the forward path by multiplying the plant and controller zTF:
numfp=conv(numdc,numdp);  % the conv(olution) command multiplies out
denfp=conv(dendc,dendp);  % polynomial coefficients

% add unity negative feedback loop:
[numcl,dencl]=cloop(numfp,denfp,-1);


% simulate and plot:
% Just the dstep command would do if an x-axis in sample numbers
% was adequate.  To get proper time axis, store values and plot
% separately against t:
[y,x]=dstep(numcl,dencl,nmax);
plot(t,y),grid

% add 'analogue' plot for comparison
hold on          % freeze plot in window
ta=[0:0.1:tmax];
nfl=conv(1.5*[1  1],nump);     % Laplace forward path numerator
dfl=conv([1  3],denp);         % Laplace forward path denominator
[ncll,dcll]=cloop(nfl,dfl,-1); % Laplace closed-loop TF
[ya,xa]=step(ncll,dcll,ta);
plot(ta,ya)
hold off         % release plot window




disp(' ')
disp(' Plot is for ''simple method''')
disp(' (Lower trace is analogue controller)')
disp(' To try different method, edit the file where shown')
disp(' ')


