% creates responses of antenna positioner, and feedback loops
% (fig 5.4). Values are from example 5.4
%

% Ken Dutton 1994

% Remove comments from three lines ******* to display input signal

% The lsim  command is used at the end of the file, as noted in the text.
 
disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')

%
% plant:
clear
clg
hold off
a=[0  1  0; 0  -1  1; 0  0  -5]; b=[0  0  5]'; c=[1  0  0]; d=0;
%
% feedback:
k=[10  2.8  1.2];
%
% make states x2 and x3 into outputs y2 and y3, so that they are available
% for feedback (augstate command could be used instead):
%
c=eye(3);
d=[0  0  0]';
%
%*************************
% add input as y4 so that input signal level can be inspected
%c=[c; 0  0  0];  % no state contribution to y4
%d=[d; 1];        % direct i/p contribution to y4
%k=[k  0];        % no f/b connection from y4
%*************************
%
% add feedback to form closed-loop scheme (-ve f/back via k):
[ac,bc,cc,dc]=feedback(a,b,c,d,[],[],[],k,-1);
%
disp('Poles of closed loop system are (should be -1+j2, -1-j2, -10):')
eig(ac)
%
[y,x,t]=step(ac,bc,cc,dc); % necessary to save data so as to be able to
%                            get them on same plot
plot(t,y);grid

%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig5_5
%
% matlab 3.5 print:
%meta fig5_5
%!gpp fig5_5 /dhpgl /ol


%
% Now demonstrate the regulatory action using  lsim 
% as suggested in the text:

disp(' ')
disp(' Fig 5.4 is currently displayed')
disp(' ')
disp(' Now press any key to see the regulator reject')
disp(' a set of non-zero initial state disturbances')
pause

% use same closed-loop model and time axis values as calculated above.

r=zeros(size(t));  % sets up reference input = 0 at every time step
x0=[1  1  1]' ;    % arbitrary set of non-zero initial conditions on the
                   % state vector (note the transpose)
lsim(ac,bc,cc,dc,r,t,x0),grid    % do the simulation and plot responses
