function [ret,x0,str,ts,xts]=fig7_10(t,x,u,flag);
%FIG7_10	is the M-file description of the SIMULINK system named FIG7_10.
%	The block-diagram can be displayed by typing: FIG7_10.
%
%	SYS=FIG7_10(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes FIG7_10 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling FIG7_10 with a FLAG of zero:
%	[SIZES]=FIG7_10([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[145,175,645,475])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '5')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[20,45,40,65])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+-',...
		'position',[70,50,90,70])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','Kalman Controller'])
set_param([sys,'/','Kalman Controller'],...
		'Numerator','[1.9001  -1.6572  0.2571   0   0]',...
		'Denominator','[1  0   0  -0.6595  -0.3405]',...
		'Sample time','.4',...
		'position',[105,34,275,86])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y',...
		'position',[455,52,505,68])

add_block('built-in/Transfer Fcn',[sys,'/','Plant'])
set_param([sys,'/','Plant'],...
		'Numerator','8',...
		'Denominator','[1 5 4]',...
		'position',[345,41,405,79])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay']])
set_param([sys,'/',['Transport',13,'Delay']],...
		'Delay Time','.8',...
		'position',[290,45,330,75])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[415,141,445,174])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','u',...
		'position',[320,192,370,208])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','2.000000',...
		'Hgain','5.000000',...
		'Vmax','4.000000',...
		'Hmax','10.000000',...
		'Window',[10,78,341,392])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[460,145,490,175])
add_line(sys,[95,60;100,60])
add_line(sys,[410,60;425,60;425,120;55,120;65,65])
add_line(sys,[335,60;340,60])
add_line(sys,[280,60;285,60])
add_line(sys,[410,60;450,60])
add_line(sys,[45,55;65,55])
add_line(sys,[280,60;280,200;315,200])
add_line(sys,[450,160;455,160])
add_line(sys,[280,165;410,165])
add_line(sys,[355,120;355,150;410,150])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
