function [ret,x0,str,ts,xts]=fig7_11(t,x,u,flag);
%FIG7_11	is the M-file description of the SIMULINK system named FIG7_11.
%	The block-diagram can be displayed by typing: FIG7_11.
%
%	SYS=FIG7_11(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes FIG7_11 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling FIG7_11 with a FLAG of zero:
%	[SIZES]=FIG7_11([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[30,175,645,475])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+-',...
		'position',[75,50,95,70])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[25,45,45,65])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','Dahlin controller'])
set_param([sys,'/','Dahlin controller'],...
		'Numerator','[0.5222  -0.4555  0.07067   0   0]',...
		'Denominator','[1  -0.30245  -0.4227  -0.18127  -0.09358]',...
		'Sample time','.4',...
		'position',[110,34,380,86])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','1.000000',...
		'Hgain','10.000000',...
		'Vmax','2.000000',...
		'Hmax','20.000000',...
		'Window',[10,77,341,391])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[585,145,615,175])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','u',...
		'buffer','1050',...
		'position',[445,192,495,208])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[540,141,570,174])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay']])
set_param([sys,'/',['Transport',13,'Delay']],...
		'Delay Time','.8',...
		'position',[415,45,455,75])

add_block('built-in/Transfer Fcn',[sys,'/','Plant'])
set_param([sys,'/','Plant'],...
		'Numerator','8',...
		'Denominator','[1 5 4]',...
		'position',[470,41,530,79])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y',...
		'buffer','1050',...
		'position',[580,52,630,68])
add_line(sys,[100,60;105,60])
add_line(sys,[535,60;550,60;550,120;60,120;70,65])
add_line(sys,[460,60;465,60])
add_line(sys,[385,60;410,60])
add_line(sys,[535,60;575,60])
add_line(sys,[50,55;70,55])
add_line(sys,[575,160;580,160])
add_line(sys,[480,120;480,150;535,150])
add_line(sys,[385,60;395,60;395,165;535,165])
add_line(sys,[395,165;395,200;440,200])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
