% creates responses of second order plant and reduced-order
% observer (fig 9.10)
% values are from example 9.2
%

% Ken Dutton 1994

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')

% plant:
a=[0 1;-4 -3]; b=[0 1]'; c=[1 0];
%
% observer:
f=-15; g=-184; jo=1; to=[-12 1];
ctinv=inv([c; to]);
%
% combine plant and observer into a single model with states [x  z]', and
% set up C and D to make plant states and observer o/p (Z) available:
ao=[a  zeros(2,1); g*c  f];
bo=[b; jo];
co=eye(3);
do=[0; 0; 0];
%
% set up initial conditions w. plant o/p steady at 1 unit and observer at zero
x0=[1; 0; 0];
%
% set up time and input vectors and simulate:
t=[0:1/150:5];         % time step 1/10 of observer time constants
u=4*ones(length(t),1); % plant gain 0.25, therefore sets initial o/p at 1
stp=150;               % point of application of unit step
u([stp:length(t)],1)=8*ones((length(t)+1-stp),1); % step up to 2 units
[y,x]=lsim(ao,bo,co,do,u,t,x0);
%
% y now has columns 1 & 2 = x1 and x2, column 3 = z.
% add cols. 4 and 5 as estimates of x1 and x2, and plot states and estimates:
est=zeros(length(t),2);
for k = 1:length(t)
   est(k,:)=[ctinv*[y(k,1); y(k,3)]]';
end
y=[y est];
plot(t,y(:,[1 2 4 5])),grid,xlabel('time (s)'), ylabel('amplitude')
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_10
%
% matlab 3.5 print:
%meta fig9_10
%!gpp fig9_10 /dhpgl /ol
