% creates responses of antenna positioner, reduced-order observer,
% feedback loops and tracking integrator. This is the system of
% fig. 9.19, but this simulation is based on the matrix methods
% used for fig 9.14, as a cross check on the results.
%
% values are from example 9.3

% Ken Dutton 1994

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')
%
% plant:
clear
clg
hold off
a=[0  1  0; 0  -1  1; 0  0  -5]; b=[0  0  5]'; c=[1  0  0];
%
% observer:
f=[-35  1; -225  -5]; g=[-965  -8775]'; jo=[0  5]';
to=[-34  1  0; -225  0  1];  ksvf=[160  68.8 7.2]; ki=300;
ctinv=inv([c; to]);
%
% combine plant and observer into a single model with states [x  z]', and
% set up C and D to make plant states and observer o/p (Z) available:
ao=[a-b*ksvf   zeros(3,2); g*c-to*b*ksvf   f];
bo=[b; jo];
co=eye(5);
do=zeros(5,1);
%
% add series integrator and close loop:
num=ki;
den=[1 0];
[ai,bi,ci,di]=tf2ss(num,den);
[af,bf,cf,df]=series(ai,bi,ci,di,ao,bo,co,do);
[ac,bc,cc,dc]=cloop(af,bf,cf,df,1,-1);
%
% set up c and d to make xi (integrator o/p) available as y6:
cc=eye(6);
dc=zeros(6,1);
%
%
% set up time and input vectors and simulate:
t=[0:0.005:8];         % time step 5ms
u=zeros(length(t),1);
%u(1:10)=27.8*10*ones(1:10);
%u(11:15)=-19.88*27.8*ones(1:5);
%u(16:18)=27.8*ones(1:3);
stp=400;               % point of application of unit step

u([stp:length(t)],1)=ones((length(t)+1-stp),1); % step ref up to 1 unit
[y,x]=lsim(ac,bc,cc,dc,u,t);
%
% y now has column 1 = xi, columns 2, 3 & 4 = x1, x2 and x3,
% columns 5 & 6 = z1 and z2.
% add cols. 7, 8 and 9 as estimates of x1, x2 and x3, and plot w. states:
est=zeros(length(t),3);
for k = 1:length(t)
   est(k,:)=[ctinv*[y(k,2); y(k,5); y(k,6)]]';
end
y=[y est];
plot(t,y(:,[2 3 4 7 8 9])),grid,xlabel('time (s)'), ylabel('amplitude')
pause
plot(t,y(:,[2 7])),grid,title('x1 & estimate')
pause
plot(t,y(:,[3 8])),grid,title('x2 & estimate')
pause
plot(t,y(:,[4 9])),grid,title('x3 & estimate')
pause
while 0
axis([6 12 -0.2 0.4]);
plot(t(stp+1:length(t)),y((stp+1:length(t)),[1 2 3 7 8 9])),grid,xlabel('time (s)'), ylabel('amplitude')
end