% creates responses of antenna positioner, reduced-order observer and
% feedback loops with tracking action. System is shown in Fig. 9.17,
% plots are not given in text.
%
% values are from example 9.3/9.4

% Ken Dutton 1994

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')

%
% plant:
clear
clg
hold off
a=[0  1  0; 0  -1  1; 0  0  -5]; b=[0  0  5]'; c=[1  0  0];
%
% observer:
f=[-35  1; -225  -5]; g=[-965  -8775]'; jo=[0  5]';
to=[-34  1  0; -225  0  1]; ksvf=[10  2.8  1.2];
ctinv=inv([c; to]);
%
% modify feedback gains, and add integral action gain:
ksvf=[160  68.8  7.2];
numint=300;   % integral gain
denint=[1 0]; % integrator denominator
[ai,bi,ci,di]=tf2ss(numint,denint); % state-space form of integrator
%
% combine plant and observer into a single model with states [x  z]', and
% set up C and D to make plant states and observer o/p (Z) available:
ao=[a-b*ksvf   zeros(3,2); g*c-to*b*ksvf   f];
bo=[b; jo];
co=eye(5);
do=zeros(5,1);
%
% add series integrator and close loop:
[af,bf,cf,df]=series(ai,bi,ci,di,ao,bo,co,do);
[ac,bc,cc,dc]=cloop(af,bf,cf,df,1,-1);
[yy,xx,t]=step(ac,bc,cc,dc,1);
plot(t,yy(:,[1:3])),grid
pause
disp('')
disp(' Closed-loop poles are:')
disp('')
eig(ac)
