%
% Creates fig. 9.19 - digital simulation of flowchart of fig. 9.18
%
% no high-level commands used - mimic any other programming language
% except for matrix multiplication etc (MATLAB
% is very slow used this way though!)

% Ken Dutton 1994

%
disp(' ')
disp(' The calculations take a while (30 sec on 486DX 33) - please wait!')
disp(' ')
disp(' Warning messages can usually be ignored')
disp(' ')
disp(' Error messages mean that the workspace should be')
disp(' cleared and the program re-run')
disp(' ')
disp(' Press any key after noting these comments')
pause

%
% matrix multiplication and addition have been used - but would be easily
% programmed as separate procedures in other languages.
%
% initialise known variables:
%
% split the feedback gain k in to ky and kz for easier execution:
ky=4119.2;     % SVF gain from y
kz(1,1)=68.8;  % SVF gains from z
kz(1,2)=7.2;
jj(1,1)=0;     % observer input from u
jj(2,1)=5;
g(1,1)=-965;   % observer input from y
g(2,1)=-8775;
f(1,1)=-35;    % observer plant matrix
f(1,2)=1;
f(2,1)=-225;
f(2,2)=-5;
hobs=0.005;    % observer sampling period
%%%hobs=0.001; % 1ms version (look for %%% to find other mods for this)
ki=300;        % tracking integrator gain
%
% Observer discrete-time model (five terms of power series):
%
pho(1,1)=1;    % first term in phi = unit matrix
pho(1,2)=0;
pho(2,1)=0;
pho(2,2)=1;
dto(1,1)=0;    % delta initialised to 0 (2x2 at this stage because
               % postmultiplication by jj and g is left till the end)
dto(1,2)=0;
dto(2,1)=0;
dto(2,2)=0;
pterm=pho;     % current term in expansion of phi
for i = 1:5
   dterm=pterm*hobs/i;  % current term in expansion of delta
   dto=dto+dterm;
   pterm=f*dterm;       % next term in expansion of phi
   pho=pho+pterm;
end
pho=pho-pterm;          % restrict phi to same number of terms as delta
dtu=dto*jj;    % delta vector from u
dty=dto*g;     % delta vector from y
%
% calculate discrete-time model of plant (may as well use same sample period):
%
a(1,1)=0;
a(1,2)=1;
a(1,3)=0;
a(2,1)=0;
a(2,2)=-1;
a(2,3)=1;
a(3,1)=0;
a(3,2)=0;
a(3,3)=-5;
b(1,1)=0;
b(2,1)=0;
b(3,1)=5;
c(1,1)=1;      % o/p eq. not really necessary - could just use x1. Included
c(1,2)=0;      % to illustrate general case
c(1,3)=0;
php(1,1)=1;    % first term in phi = unit matrix
php(1,2)=0;
php(1,3)=0;
php(2,1)=0;
php(2,2)=1;
php(2,3)=0;
php(3,1)=0;
php(3,2)=0;
php(3,3)=1;
dtp(1,1)=0;    % delta initialised to 0 (3x3 at this stage because
               % postmultiplication by b is left till the end)
dtp(1,2)=0;
dtp(1,3)=0;
dtp(2,1)=0;
dtp(2,2)=0;
dtp(2,3)=0;
dtp(3,1)=0;
dtp(3,2)=0;
dtp(3,3)=0;
pterm=php;     % current term in expansion of phi
for i = 1:5
   dterm=pterm*hobs/i;  % current term in expansion of delta
   dtp=dtp+dterm;
   pterm=a*dterm;       % next term in expansion of phi
   php=php+pterm;
end
php=php-pterm;          % restrict phi to same number of terms as delta
dtp=dtp*b;              % delta vector from u
%
% observer initial conditions:
%
zold(1,1)=0;
zold(2,1)=0;
%
% plant initial conditions:
xold(1,1)=0;
xold(2,1)=0;
xold(3,1)=0;
yold=0;
%
%
% set up input streams:
tend=8;          % end time for simulation (sec)
i=[0:hobs:tend];  % index for variables
%
% manual pot position (arbitrary, but chosen to give steady state of
% 0.5, and fast settling w.r.t. plant dynamics):
uman=zeros(i);
uman(1:10)=27.8*10*ones(1:10);
uman(11:15)=-19.88*27.8*ones(1:5);
uman(16:18)=27.8*ones(1:3);
%%%uman(1:50)=27.8*10*ones(1:50);    % 1ms version 
%%%uman(51:75)=-19.88*27.8*ones(1:25);
%%%uman(76:90)=27.8*ones(1:15);
%
% auto/manual switch (changes to 1 for auto after 1.5 seconds):
sw=zeros(i);
sw(length(i)*1.5/tend+1:length(i))=ones(1,(length(i)-1-length(i)*1.5/tend));
%
% computer additional step (steps to 1 after 2 seconds):
rstp=zeros(i);
rstp(length(i)*2/tend+1:length(i))=ones(1,(length(i)-1-length(i)*2/tend));
%
%
% initialise length of output variables (saves a lot of execution time)
% would already have been done by declaration statements in other languages.
%
t=zeros(i);      % for time from zero to tend seconds at hobs = 0.005 steps
tm1=length(t)-1; % length of other arrays
x=zeros(3,tm1);
z=zeros(2,tm1);
y=zeros(1,tm1);
%
% start of main program loop (would loop for ever if controlling plant)
%
index=1;
t(1)=0;
svf=0;
for ii = 1:tm1/4 % only executes overall loop every four observer executions 
   if sw(index)==0
      %
      % in manual mode
      %
      % 3 executions of observer model:
      %%% (19 for 1ms version)
      %
      for k=index:index+2
%%%   for k=index:index+18  % 1ms version
         t(k+1)=t(k)+hobs;            % store times for plotting only
         x(:,k)=xold;                 % store states for plotting only
         y(:,k)=yold;                 % store output for plotting only
         z(:,k)=zold;                 % store obs o/p for plotting only
         xold=php*xold+dtp*uman(k);   % plant model - update states
         zold=pho*zold+dtu*uman(k)+dty*yold;   % observer model - update obs
         yold=c*xold;                 % now update o/p to same step as states
      end
      %
      % fourth execution of observer:
      %%% (twentieth for 1ms version)
      k=index+3;
%%%   k=index+19;   % 1ms version
      t(k+1)=t(k)+hobs;            % store times for plotting only
      x(:,k)=xold;                 % store states for plotting only
      y(:,k)=yold;                 % store output for plotting only
      z(:,k)=zold;                 % store obs o/p for plotting only
      xold=php*xold+dtp*uman(k);   % plant model
      zold=pho*zold+dtu*uman(k)+dty*yold;   % observer model
      %
      % track manual input:
      xiold=(uman(k)+svf)/ki;
      yold=c*xold;           % update o/p to same step as states
      %
      % calculate SVF:
      svf=ky*yold+kz*zold;   % svf at same step as states
      %
      r=yold;                % required ref at same step as states
      index=index+4;
%%%   index=index+20;   % 1ms version
   else
      %
      % in automatic mode
      %
      u=ki*xiold-svf;                 % plant i/p - only update every 20ms
      %
      % 3 executions of observer model + integrator model:
      %%% (19 for 1ms version)
      %
      for k=index:index+2
%%%   for k=index:index+18   % 1ms version
         t(k+1)=t(k)+hobs;            % store times for plotting only
         x(:,k)=xold;                 % store states for plotting only
         y(:,k)=yold;                 % store output for plotting only
         z(:,k)=zold;                 % store obs o/p for plotting only
         xold=php*xold+dtp*u;         % plant model
         zold=pho*zold+dtu*u+dty*yold;   % observer model
         xidot=r+rstp(k)-yold;        % tracking integrator i/p
         xiold=xiold+hobs*xidot;      % tracking integrator o/p
         yold=c*xold;
      end
      %
      % fourth execution of observer + tracking integrator:
      %%% (twentieth for 1ms version)
      k=index+3;
%%%   k=index+19;   % 1ms version
      t(k+1)=t(k)+hobs;            % store times for plotting only
      x(:,k)=xold;                 % store states for plotting only
      y(:,k)=yold;                 % store output for plotting only
      z(:,k)=zold;                 % store obs o/p for plotting only
      xold=php*xold+dtp*u;         % plant model
      zold=pho*zold+dtu*u+dty*yold;   % observer model
      xidot=r+rstp(k)-yold;        % tracking integrator i/p
      xiold=xiold+hobs*xidot;      % tracking integrator o/p
      %
      % calculate SVF:
      yold=c*xold;
      svf=ky*yold+kz*zold;
      %
      index=index+4;
%%%   index=index+20;   % 1ms version
   end
end
%
% plotting of results:
%
t=t(1:length(t)-1);  % remove extra time value
%%%t=t(1:length(t)-2);  % 1 ms version. NB may have memory problems here
plot(t,y),grid       % plot o/p response
disp('')
disp(' Output plot is present')
disp('')
disp(' Press a key to see estimates, etc.')
disp('')
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_19a
%
% matlab 3.5 print:
%meta fig9_19a
%!gpp fig9_19a /dhpgl /ol
%
ctinv=[1 0 0;34 1 0;225 0 1];  % form inverse of [c  T]'
xhat=ctinv*[x(1,:);z];         % create state estimates from x(1) & z
plot(t,[x;xhat]),grid          % plot states and estimates
pause
plot(t(300:length(t)),[x(:,300:length(t));xhat(:,300:length(t))]),grid
%%%plot(t(1500:length(t)),[x(:,1500:length(t));xhat(:,1500:length(t))]),grid
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_19b
%
% matlab 3.5 print:
%meta fig9_19b
%!gpp fig9_19b /dhpgl /ol
