%
% Uses all the high-level MATLAB commands to cross-check the
% performance of fig9_19.m in producing fig. 9.19
%
% there are 6 places where lines can be commented out to change from
% the full tracking system to the SVF regulator only (marked %r%)
%
% there are 4 places where lines can be commented out to change from
% discrete-time to continuous time (marked %c%)

% Ken Dutton 1994

disp(' ')
disp(' Ignore following ''warnings''')
disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')
disp(' Press any key after noting these comments')
pause

%
% initialise known variables:
%
ky=4119.2;      % SVF gain from y
kz=[68.8  7.2]; % SVF gains from z
jj=[0; 5];      % observer input from u
g=[-965; -8775];% observer input from y
f=[-35  1;-225 -5];    % observer plant matrix
hobs=0.005;    % observer sampling period
%%%hobs=0.001; % 1ms version (look for %%% to find other mods for this)
ki=300;        % tracking integrator gain
%
% Observer discrete-time model
%
[pho,dtu]=c2d(f,jj,hobs);
[pho,dty]=c2d(f,g,hobs);
dto=[dty  dtu]; % single i/p matrix for observer
co=eye(2);
do=zeros(2);
%
% discrete-time model of plant:
%
a=[0  1  0; 0  -1  1; 0  0  -5];
b=[0  0  5]';
c=[1  0  0];
d=0;
[php,dtp]=c2d(a,b,hobs);
%
% set up input streams:
tend=8;          % end time for simulation (sec)
t=[0:hobs:tend];  % time vector
%
% manual pot position (arbitrary, but chosen to give steady state of
% 0.5, and fast settling w.r.t. plant dynamics):
uman=zeros(t);
uman(1:10)=27.8*10*ones(1:10);
uman(11:15)=-19.88*27.8*ones(1:5);
uman(16:18)=27.8*ones(1:3);
%%%
%%%uman(1:50)=27.8*10*ones(1:50);    % 1ms version 
%%%uman(51:75)=-19.88*27.8*ones(1:25);
%%%uman(76:90)=27.8*ones(1:15);
%
% computer additional step (steps to 1 after 2 seconds):
rstp=zeros(t);
rstp(length(i)*2/tend+1:length(i))=ones(1,(length(i)-1-length(i)*2/tend));
%
%r%
% next two lines are for checking SVF regulator only. Comment-out for tracker
% N.B. Apart from these 2 lines, 7 other lines need commenting in or out below
%ky=375.2;
%kz=[2.8  1.2];
%
% Manual control phase (first 1.5 sec):
%
tm=[0:hobs:1.5]; % time for manual phase
%
% Form parallel connection of plant and obs, with plant i/p 1 and obs i/p
% 2 common, and no summed outputs. Thus, u2 = remaining observer i/p,
% y1 = plant o/p (y) & y2, y3 = observer o/ps (z)
%
[af,bf,cf,df]=parallel(php,dtp,c,d,pho,dto,co,do,1,2,[],[]);
%
%c%
%[af,bf,cf,df]=parallel(a,b,c,d,f,[g  jj],co,do,1,2,[],[]); % cont. time ver.
[af,bf,cf,df]=cloop(af,bf,cf,df,1,2);  % connects plant o/p1 to obs i/p (2)
[af,bf,cf,df]=ssdelete(af,bf,cf,df,2,[]); % remove spare 2nd i/p
%
u=uman(1:length(tm))'; % input stream for manual control period
[yman, xman]=dlsim(af,bf,cf,df,u); % simulate
%
%c%
%[yman, xman]=lsim(af,bf,cf,df,u,tm); % simulate - this line for cont. time
%
% Automatic phase:
%
ta=[1.5+hobs:hobs:tend]; % time for auto phase
%
[ac,bc,cc,dc]=feedback(af,bf,cf,df,[],[],[],[ky  kz],-1,[1:3]); % adds SVF
%
%r%
%while 0  % prevents tracking integrator being added if testing SVF regulator
         % only. Comment-out for whole system
   % Add tracking integrator:
   %
   [ai,bi,ci,di]=tf2ss(ki,[1  0]);
   [phi,dti]=c2d(ai,bi,hobs);
   [ao,bo,co,do]=series(phi,dti,ci,di,ac,bc,cc,dc);  % discrete series integ.
   %
   %c%
   %[ao,bo,co,do]=series(ai,bi,ci,di,ac,bc,cc,dc); % continuous series integ.
   [ac,bc,cc,dc]=feedback(ao,bo,co,do,[],[],[],1,-1,1);  % o/p feedback loop
   %
%r%
%end
%
% use end of manual phase to generate initial conditions:
x0=xman(length(tm),:);  % plant and observer initial states
xi=[ky  kz]*yman(length(tm),:)'/300;  % integrator initial state
%
%r%
x0=[xi; x0'];  % comment-out this line if not using tracking integrator
%
r=rstp(length(tm)+1:length(rstp));
%
%
%r%
r=r+yman(length(tm),1);     % initialise ref i/p for tracking system
%r=r+ [ky  kz]*yman(length(tm),:)';  % initialise ref i/p for regulator system
%
[yaut, xaut]=dlsim(ac,bc,cc,dc,r',x0); % discrete-time simulation
%
%c%
%[yaut, xaut]=lsim(ac,bc,cc,dc,r',ta,x0); % this line for cont. time version
y=[yman; yaut];
t=[tm  ta];
plot(t,y),grid
pause
plot(t,y(:,1)),grid
pause
%
% now plot states and estimates:
%
% xaut(2) to xaut(4) contain plant states in auto (1 becomes integrator state)
%
%
%r%
x=[xman(:,1:3); xaut(:,2:4)];  % use this line for tracking system
%x=[xman(:,1:3); xaut(:,1:3)];   % use this line for regulator system
%
%
% y(1) is plant o/p y(2) and y(3) are z1 and z2 from observer
% 
% observer t matrix and state estimates:
ct=[1  0  0;-34 1 0; -225 0 1];
xhat=inv(ct)*y';
xhat=xhat';
plot(t,[x  xhat]),grid
pause
rge=[300:length(t)];
plot(t(rge),[x(rge,:) xhat(rge,:)]),grid 
pause
