% creates Kalman filter & responses for fig 9.24
%

% Ken Dutton 1994

disp(' ')
disp(' Ignore ''warnings'' during execution of this file')
disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')
disp(' Press any key after noting these comments')
pause


% usual system
%
hold off
clg
a=[0 1 0; 0 -1 1; 0 0 -5]; b=[0 0 5]'; c=[1 0 0]; d=0;
%
% make states x1:x3 appear as o/ps y2:y4 for f/back & checking:
%
[ap,bp,cp,dp]=augstate(a,b,c,d);
%
% to be able to add system noise to drive o/p and load o/p (x3, x2)
% requires two new inputs u2 and u3 feeding x2 and x3:
%
bp=[bp [0 1 0]' [0 0 1]'];       % now 3x3
dp=[dp [0 0 0 0]' [0 0 0 0]'];   % now 4x3
%
% to be able to add measurement noise to position o/p
% requires another new input u4 feeding y:
%
bp=[bp [0 0 0]'];       % now 3x4
dp=[dp [1 0 0 0]'];     % now 4x4
%
% The model [ap,bp,cp,dp] now has the original 3 states;
% u1=ref i/p, u2 feeds x2 (load), u3 feeds x3 (drive o/p), u4 feeds y1;
% y1=o/p (x1+u4), y2=x1, y3=x2, y4=x3.
%
% add former SVF with tracking integrator to allow checking of responses:
kf=[160  68.8  7.2];
ki=300;
[ac,bc,cc,dc]=feedback(ap,bp,cp,dp,[],[],[],kf,-1,[1 3 4]);
[ai,bi,ci,di]=tf2ss(ki,[1 0]);  % tracking integrator
%
% Using the series command to put the integrator in series with the Plant &
% SVF, will lose all the extra inputs we made for the plant. To avoid this,
% the integrator model needs altering so that it has extra inputs u2:u4, which
% directly feed to extra outputs y2:y4. Then, when the series connection is
% made, the output of the integrator (y1) will be connected to the original
% plant input (u1), and the extra inputs (u2:u4) will be connected straight
% through y2:y4 onto the plant noise inputs u2:u4 we defined earlier.
%
bi=[bi 0 0 0];     % adds 3 extra inputs to integrator model
ci=[ci; 0; 0; 0];  % adds 3 extra outputs to integrator model
di=[di zeros(1,3); zeros(3,1)  eye(3)]; % connects new i/ps & o/ps directly
%
[af,bf,cf,df]=series(ai,bi,ci,di,ac,bc,cc,dc);   % series w. SVF & plant
%
%
[ac,bc,cc,dc]=feedback(af,bf,cf,df,[],[],[],1,-1,1); % add UNF loop
%
% store noise-free responses for reference later:
h=0.01;
t=[0:h:7];
[xorg,xorg]=step(ac,bc,cc,dc,1,t);
plot(t,xorg),grid,title('step on ref i/p - noise-free')
pause
%
while 0  % comment-out to see other input step responses
   [y,y]=step(ac,bc,cc,dc,2,t);
   plot(t,y),grid,title('step on load velocity')
   pause
   [y,y]=step(ac,bc,cc,dc,3,t);
   plot(t,y),grid,title('step on drive o/p')
   pause
   [y,y]=step(ac,bc,cc,dc,4,t);
   plot(t,y),grid,title('step on o/p')
   pause
end
%
% 
% Define noise inputs:
u=zeros(length(t),4);
%
rand('normal')
% o/p noise:
u(:,4)=0.05*rand(t'); % o/p measurement noise
u(:,3)=0.1*rand(t');  % noise on drive system o/p
u(:,2)=0.1*rand(t');  % noise on load velocity
u(:,1)=ones(t');      % reference step
%
%
while 0 %%%%%%%%%%%%% comment-out for full-order observer %%%%%%%%%%%%%%%%%%%
%                (together with the matching  'end'  statement)
%
% now replace direct SVF with full-order observer + SVF. This means that we
% initially remove the tracking system and SVF loops, and revert to the model
% [ap,bp,cp,dp] having the original 3 states; u1=ref i/p, u2 feeds x2 (load),
% u3 feeds x3 (drive o/p), u4 feeds y1; y1=o/p (x1+u4), y2=x1, y3=x2, y4=x3.
%
% At this point, change to discrete-time (for KF later)
%
[php,dlp]=c2d(ap,bp,h);
%
obspols=[-19 -20 -21];    % observer pole locations
g=place(a',c',obspols)';  % design g matrix for observer
f=a-g*c;                  % design f matrix for observer
%
% To allow connection of the observer, define a 5th plant o/p, equal to the
% reference i/p u1 (no tracking integrator yet, remember).
%
cp=[cp; [0 0 0]];    % now 5x3
dp=[dp; [1 0 0 0]];  % now 5x4
% 
% Next define the observer to have two inputs: one from the ref i/p (now y5)
% (to be fed in via b), and one from the plant o/p (noisy version - y1) (to be
% fed in via g). The series command can then be used to make the connection.
%
% Note that the series command will also 'lose' the extra o/ps of the plant
% model which do not feed the observer. Therefore it is also necessary to
% give the observer four 'spare' o/ps, connected directly to four 'spare'
% observer inputs, so as to pass the existing outputs straight through it.
%
aobs=f;
zc=[0 0 0]';         % column of zeros for building up observer i/p matrix
bobs=[g zc zc zc b];
cobs=[zeros(4,3);eye(3)];  % y1:4 original o/ps, y5:7 estimates
zc=[0 0 0 0 0 0 0]'; % column of zeros for building up observer o/p matrix
dobs=[[eye(4);zeros(3,4)]  zc];
[pho,dlo]=c2d(aobs,bobs,h);   % discrete-time version
[af,bf,cf,df]=series(php,dlp,cp,dp,pho,dlo,cobs,dobs);
%
% The model [af,bf,cf,df] now includes the plant and full-order observer.
% It has the original 3 states as x1:3, and the estimates as x4:x6;
% u1=ref i/p, u2 feeds x2 (load), u3 feeds x3 (drive o/p), u4 feeds y1;
% y1=o/p (x1+u4), y2=x1, y3=x2, y4=x3, y5=x1hat, y6=x2hat, y7=x3hat.
%
%
% Now add SVF and tracking integrator back in:
%
%[ac,bc,cc,dc]=feedback(af,bf,cf,df,[],[],[],kf,-1,[1 3 4]); % SVF real states 
[ac,bc,cc,dc]=feedback(af,bf,cf,df,[],[],[],kf,-1,5:7);    % SVF estimates
%
[phi,dli]=c2d(ai,bi,h); % discrete-time integrator model
[af,bf,cf,df]=series(phi,dli,ci,di,ac,bc,cc,dc);   % series w. integrator
%
%
[ac,bc,cc,dc]=feedback(af,bf,cf,df,[],[],[],1,-1,1); % add UNF loop
%
% look at noise-free responses to check:
dstep(ac,bc,cc,dc,1,length(t)),grid,title('step on ref i/p - noise-free')
pause
%
while 0  % comment-out to see other input step responses
   dstep(ac,bc,cc,dc,2,length(t)),grid,title('step on load velocity')
   pause
   dstep(ac,bc,cc,dc,3,length(t)),grid,title('step on drive o/p')
   pause
   dstep(ac,bc,cc,dc,4,length(t)),grid,title('step on o/p')
   pause
end
%
%
dlsim(ac,bc,cc,dc,u),grid
pause
%
% plot original noise-free and new controlled states for comparison:
[y,x]=dlsim(ac,bc,cc,dc,u);
%plot(t,[xorg  y(:,[1 3 4])]),grid
plot(t,[xorg  y(:,[1 3])]),grid  % omit x3hat - too noisy
pause
plot(t,y(:,[2  5])),grid,title('x1 and estimate')
pause
plot(t(1:100),y(1:100,[2  5])),grid,title('x1 and estimate')
pause
plot(t,y(:,[3  6])),grid,title('x2 and estimate')
pause
plot(t(1:100),y(1:100,[3  6])),grid,title('x2 and estimate')
pause
plot(t,y(:,[4  7])),grid,title('x3 and estimate')
pause
plot(t(1:100),y(1:100,[4  7])),grid,title('x3 and estimate')
pause
%
%
end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%
% now replace observer + SVF with Kalman filter + SVF. This means that we
% initially remove the tracking system and SVF loops, and revert to the model
% [ap,bp,cp,dp] having the original 3 states; u1=ref i/p, u2 feeds x2 (load),
% u3 feeds x3 (drive o/p), u4 feeds y1; y1=o/p (x1+u4). 
%
% y2=x1, y3=x2, y4=x3 can be stored during simulation
%
ap=[0 1 0; 0 -1 1; 0 0 -5]; bp=[0 0 5]'; cp=[1 0 0]; dp=0;
bp=[bp [0 1 0]' [0 0 1]'];       % now 3x3
dp=[dp  0  0];                   % now 1x3
bp=[bp [0 0 0]'];       % now 3x4
dp=[dp  1];             % now 1x4
%
% The model [ap,bp,cp,dp] now has the original 3 states;
% u1=ref i/p, u2 feeds x2 (load), u3 feeds x3 (drive o/p), u4 feeds y1;
% y1=o/p (x1+u4).
%
% We continue to use the discrete-time version [php, dlp, cp,dp] of the plant
%
[php,dlp]=c2d(ap,bp,h);
%
% and [phi,dli,ci,di] for the tracking integrator.
[ai,bi,ci,di]=tf2ss(ki,[1 0]);  % restore ci, di to simple siso values
[phi,dli]=c2d(ai,bi,h);
%
% The SVF gains remain in kf, and the integrator gain in ki.
%
% Initialisations:
%
kkf=[0 0 0]';                    % kalman gain (only done for
                                 % consistency between runs really)
pold=diag([10000 10000 10000]);  % initial poor Riccati solution
xhatold=[0  0  0]';              % initial filter estimates
q=diag([0  0.1^2  0.1^2]);       % no noise on x1; x2 and x3 from definition
r=0.05^2;                        % from definition of measurement noise
gama=diag([0  1  1]);            % no noise on x1
xold=[0 0 0]';                   % initial plant states
yold=0;                          % initial plant o/p
xiold=0;                         % initial integrator state
yiold=0;                         % initial integrator o/p
ct=29;                           % iteration indicator
y=zeros(length(t),7);            % first 4 o/p as above, 5:7 for xhat
%
% iterate:
for jj=1:length(t)
   ct=ct+1;
   if ct==30
      disp(['at loop ' int2str(jj) ' out of ' int2str(length(t)) ...
        ' gain = ' num2str(kkf(1)) '  ' num2str(kkf(2)) '  ' num2str(kkf(3))])
      ct=0;
   end
   %
   % tracking integrator:
   %
   uint=u(jj,1)-yold;
   xinew=phi*xiold+dli*uint;
   yinew=ci*xinew+di*uint;
   %
   % plant:
   %
   % input = u(jj,:), but with first element replaced by feedback signals,
   %       as u(jj,1) is the input to the overall scheme at the integrator
   uplant=[yiold-kf*xhatold   u(jj,2:4)];
   xnew=php*xold+dlp*uplant';
   y(jj,1)=(cp*xnew+dp*uplant')';
   y(jj,2:4)=xnew';
   %
   % Kalman filter:
   %
   pstar=php*pold*php' + gama*q*gama';
   kkf=pstar*cp'*inv(cp*pstar*cp' + r);
   xhatnew=(eye(3) - kkf*cp) * (php*xhatold + dlp*uplant') + kkf*y(jj,1);
   y(jj,5:7)=xhatnew';     % add estimates as outputs
   pnew=(eye(3) - kkf*cp) * pstar;
   %
   % updates:
   %
   yold=y(jj,1);
   xiold=xinew;
   yiold=yinew;
   xold=xnew;
   xhatold=xhatnew;
   pold=pnew;
end
%
% plot original noise-free and new controlled states for comparison:
plot(t,[xorg  y(:,[1 3 4])]),grid
pause
plot(t,[xorg  y(:,[1 3])]),grid  % omit x3hat - too noisy
pause
plot(t,y(:,[2  5])),grid,title('x1 and estimate')
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_24a
%
% matlab 3.5 print:
%meta fig9_24a
%!gpp fig9_24a /dhpgl /ol
%
plot(t(1:100),y(1:100,[2  5])),grid,title('x1 and estimate')
pause
plot(t,y(:,[3  6])),grid,title('x2 and estimate')
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_24b
%
% matlab 3.5 print:
%meta fig9_24b
%!gpp fig9_24b /dhpgl /ol
%
plot(t(1:100),y(1:100,[3  6])),grid,title('x2 and estimate')
pause
plot(t,y(:,[4  7])),grid,title('x3 and estimate')
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_24c
%
% matlab 3.5 print:
%meta fig9_24c
%!gpp fig9_24c /dhpgl /ol
%
plot(t(1:100),y(1:100,[4  7])),grid,title('x3 and estimate')
pause
