function [ret,x0,str,ts,xts]=gainspc(t,x,u,flag);
%GAINSPC	is the M-file description of the SIMULINK system named GAINSPC.
%	The block-diagram can be displayed by typing: GAINSPC.

% Ken Dutton 1994

%	SYS=GAINSPC(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes GAINSPC to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling GAINSPC with a FLAG of zero:
%	[SIZES]=GAINSPC([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[93,71,420,260])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '15')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'inputs','+-',...
		'position',[230,125,250,145])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'position',[40,85,60,105])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'position',[40,140,60,160])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','2',...
		'position',[120,116,150,149])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,133,628,460])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem/Transfer Fcn'])
set_param([sys,'/','Subsystem/Transfer Fcn'],...
		'Numerator','[1 -1]',...
		'Denominator','conv([1 1],[1 1])',...
		'position',[165,32,305,88])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem/Transfer Fcn3'])
set_param([sys,'/','Subsystem/Transfer Fcn3'],...
		'Numerator','[5 1]',...
		'Denominator','conv([1 1],[1 1])',...
		'position',[190,103,325,147])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem/Transfer Fcn1'])
set_param([sys,'/','Subsystem/Transfer Fcn1'],...
		'Numerator','[-1]',...
		'Denominator','conv([1 1],[1 1])',...
		'position',[210,169,330,211])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem/Transfer Fcn2'])
set_param([sys,'/','Subsystem/Transfer Fcn2'],...
		'Numerator','[1 -1]',...
		'Denominator','conv([1 1],[1 1])',...
		'position',[200,233,325,277])

add_block('built-in/Sum',[sys,'/','Subsystem/Sum'])
set_param([sys,'/','Subsystem/Sum'],...
		'position',[370,62,395,93])

add_block('built-in/Sum',[sys,'/','Subsystem/Sum1'])
set_param([sys,'/','Subsystem/Sum1'],...
		'position',[370,227,395,258])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','2',...
		'position',[460,141,490,174])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','2',...
		'position',[65,141,105,174])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[510,150,530,170])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[15,145,35,165])
add_line([sys,'/','Subsystem'],[110,150;195,150;205,190])
add_line([sys,'/','Subsystem'],[110,150;110,60;160,60])
add_line([sys,'/','Subsystem'],[400,80;420,80;420,150;455,150])
add_line([sys,'/','Subsystem'],[400,245;400,165;455,165])
add_line([sys,'/','Subsystem'],[110,165;115,255;195,255])
add_line([sys,'/','Subsystem'],[155,255;155,125;185,125])
add_line([sys,'/','Subsystem'],[330,125;335,125;335,85;365,85])
add_line([sys,'/','Subsystem'],[330,255;365,250])
add_line([sys,'/','Subsystem'],[310,60;365,70])
add_line([sys,'/','Subsystem'],[495,160;505,160])
add_line([sys,'/','Subsystem'],[40,155;40,160;60,160])
add_line([sys,'/','Subsystem'],[335,190;345,190;345,235;365,235])


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'position',[325,115,355,165])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[175,35,195,55])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','t',...
		'position',[315,37,365,53])

add_block('built-in/State-Space',[sys,'/','F-B_Gain'])
set_param([sys,'/','F-B_Gain'],...
		'orientation',2,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','[-1, 0; 0, 0.2]',...
		'position',[300,200,330,230])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','10.000000',...
		'Hgain','18.105600',...
		'Vmax','20.000000',...
		'Hmax','36.211200',...
		'Window',[2,56,333,480],...
		'position',[435,40,465,70])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y',...
		'position',[460,132,510,148])
add_line(sys,[295,215;205,215;205,140;225,140])
add_line(sys,[255,135;260,135;260,140;320,140])
add_line(sys,[200,45;310,45])
add_line(sys,[65,95;85,95;85,125;115,125])
add_line(sys,[65,150;85,150;85,140;115,140])
add_line(sys,[155,135;185,135;185,130;225,130])
add_line(sys,[360,140;455,140])
add_line(sys,[360,140;410,140;410,55;430,55])
add_line(sys,[360,140;385,140;385,215;335,215])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
