function inap4(w,ifplot,ccl,xmin,xmax,ymin,ymax)
%function inap4(w,ifplot,ccl,xmin,xmax,ymin,ymax)
%
% This file plots the INA for a 2*2 system whose inverse MVFR matrix is in
% ifplot, calculated for the frequencies in w.  It needs the
% Multivariable frequancy Domain Toolbox.
%
% If ccl is n, gershgorin circles are plotted every nth freq. point
% (ccl must be zero or -ve for none, 2 or more for circles).
%
% If xmin, xmax, ymin and ymax are specified, the axes are set to those values
%
% To restore plotting window issue clg; subplot(111) after use

% Ken Dutton 1993, 1995

%
% Some commands in the file are not needed for v4.2, others are not
% needed for v3.5. The file has been carefully written so that it
% will work and give acceptable (but not always visually identical)
% results in either version.
%

clg                  % clears any previous plot
%
v=version;           % detect MATLAB version ('3.5k', '4.2b', etc)
v=v(1);              % typically '3' or '4' (string) at time of writing
if v>='4'            % v is never used again after this - remainder
                     % of file common to both versions
    xys='auto';      % MATLAB version 4 (or higher) forced to auto-scaling
else
    axis([1 2 3 4]); 
    axis;            % MATLAB version 3 (or lower) forced to auto-scaling
    % later axis commands will accept xys empty in version 3
end
if nargin ~=3        % check no. of input parameters (~= means not equal to)
   if nargin ~=7
       error('inap4 needs either 3 or 7 arguments')
   end
   xys=[xmin xmax ymin ymax];  % vector of axis limits for axis command
   axis(xys)                   % fixes axes as requested
end
%
if ccl==1, ccl=2; end;  % ccl=1 causes lots of output due to MATLAB bug
%
subplot(221)
plotnyq(fget(w,ifplot,[1 1]),'g')  % plots element (1,1)
if ccl > 0
   hold on                       % fix plot whilst drawing circles on it
   circ=fcgersh(w,ifplot,1,ccl); % calculate Gershgorin circles for
                                 % element (1,1), every ccl th frequency point
   plotnyq(circ,'r')             % Gershgorin band for (1,1)
   grid
   hold off
end
axis(xys)                   % Fix axes
subplot(222)
plotnyq(fget(w,ifplot,[1 2]),'g')  % plots element (1,2)
axis(xys)                   % Fix axes
subplot(223)
plotnyq(fget(w,ifplot,[2 1]),'g')  % plots element (2,1)
axis(xys)                   % Fix axes
subplot(224)
plotnyq(fget(w,ifplot,[2 2]),'g')  % plots element (2,2)
if ccl > 0
   hold on                       % fix plot whilst drawing circles on it
   circ=fcgersh(w,ifplot,2,ccl); % calculate Gershgorin circles for
                                 % element (1,1), every ccl th frequency point
   plotnyq(circ,'r')             % Gershgorin band for (1,1)
   grid
   hold off
end
axis(xys)                   % Fix axes
