function inap9(w,ifplot,ccl,xmin,xmax,ymin,ymax)
%function inap9(w,ifplot,ccl,xmin,xmax,ymin,ymax)
%
% This file plots the INA for a 3*3 system whose inverse MVFR matrix is in
% ifplot, calculated for the frequencies in w. It will not work with
% non-Windows versions of MATLAB and requires the Multivariable Frequency
% Domain Toolbox.
%
% If ccl is n, gershgorin circles are plotted every nth freq. point
% (ccl must be zero or -ve for none, 2 or more for circles)
%
% If xmin, xmax, ymin and ymax are specified, the axes are set to those values
%
% To restore plotting window issue clg; subplot(111) after use


% Ken Dutton 1994, 1995

clg                  % clears any previous plot
hold off
%
xys='auto';
if nargin ~=3        % check no. of input parameters (~= means not equal to)
   if nargin ~=7
       error('inap9 needs either 3 or 7 arguments')
   end
   xys=[xmin xmax ymin ymax];  % vector of axis limits for axis command
end
if ccl==1, ccl=2; end;  % Can't plot circle every point due to MATLAB bug
subplot(3,3,1)
plotnyq(fget(w,ifplot,[1 1]),'g')  % plots element (1,1)
if ccl > 0
   hold on                       % fix plot whilst drawing circles on it
   circ=fcgersh(w,ifplot,1,ccl); % calculate Gershgorin circles for
                                 % element (1,1), every ccl th frequency point
   subplot(3,3,1)
   plotnyq(circ,'r')             % Gershgorin band for (1,1)
   grid
   hold off
end
axis(xys)                   % Fix axes 
subplot(3,3,2)
plotnyq(fget(w,ifplot,[1 2]),'g')  % plots element (1,2)
axis(xys)                   % Fix axes 
subplot(3,3,3)
plotnyq(fget(w,ifplot,[1 3]),'g')  % plots element (1,3)
axis(xys)                   % Fix axes 
subplot(3,3,4)
plotnyq(fget(w,ifplot,[2 1]),'g')  % plots element (2,1)
axis(xys)                   % Fix axes 
subplot(3,3,5)
plotnyq(fget(w,ifplot,[2 2]),'g')  % plots element (2,2)
if ccl > 0
   hold on                       % fix plot whilst drawing circles on it
   circ=fcgersh(w,ifplot,2,ccl); % calculate Gershgorin circles for
                                 % element (2,2), every ccl th frequency point
   subplot(3,3,5)
   plotnyq(circ,'r')             % Gershgorin band for (2,2)
   grid
   hold off
end
axis(xys)                   % Fix axes 
subplot(3,3,6)
plotnyq(fget(w,ifplot,[2 3]),'g')  % plots element (2,3)
axis(xys)                   % Fix axes 
subplot(3,3,7)
plotnyq(fget(w,ifplot,[3 1]),'g')  % plots element (3,1)
axis(xys)                   % Fix axes 
subplot(3,3,8)
plotnyq(fget(w,ifplot,[3 2]),'g')  % plots element (3,2)
axis(xys)                   % Fix axes 
subplot(3,3,9)
plotnyq(fget(w,ifplot,[3 3]),'g')  % plots element (3,3)
if ccl > 0
   hold on                       % fix plot whilst drawing circles on it
   circ=fcgersh(w,ifplot,3,ccl); % calculate Gershgorin circles for
                                 % element (3,3), every ccl th frequency point
   subplot(3,3,9)
   plotnyq(circ,'r')             % Gershgorin band for (3,3)
   grid
   hold off
end
axis(xys)                   % Fix axes 

