% fig10_10.m and fig10_11.m (presently set to generate fig10.11)
%
% alters the feedback gains of the SIMULINK model gainspc.mdl,
% so as to be able to calculate the gain space.
%
% Ken Dutton 1994
%
% Modified as below for MATLAB 5, 6.1.99
%
% diag([f(ii)  f(jj)])had to be changed to the string variable
% 'nextgain', which had to be evaluated in the separate expression
% nextgain=(diag([f(ii)  f(jj)])), 6.1.99
% Also note that gainspc.m was re-saved as gainspc.mdl
% using SIMULINK 2.2, 6.1.99
% The accompanying file  gainspc.mdl  was modified so that, in
%    SIMULINK 3, the step input block now has an explicit sampling
%    time. This avoids a huge number of warning messages in MATLAB
%    v5.3 and SIMULINK v3, but may cause a few warnings to appear in
%    MATLAB v5.2 and SIMULINK v2.2, before execution begins.  22.10.99

disp(' ')
disp(' This file requires at least SIMULINK 2 and gainspc.mdl')
disp(' ')
disp(' It may takes a long time to run.  Ignore the initial')
disp(' WARNING messages under SIMULINK 2 (SIMULINK 3 has none).')
disp(' ')
disp(' Press any key after noting these messages')
pause

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Note that this can produce either Fig. 10.10 or 10.11, depending on the
% contents of file gainspc.mdl. Edit the indicated parts of this m-file
% to change to the other figure.
%
% It will also be necessary to alter the four lines containing the
% string 'numerator' and the four lines containing the string 'denominator'
% in file gainspc.mdl (about half way through it.
% These define the transfer function matrix, and thus provide
% either the model for Fig. 10.10, or that for Fig. 10.11.
%
% You can find out which model is in place by typing gainspc at the
% MATLAB prompt, and double-clicking on the subsystem block to reveal
% its structure.  You can also change the model in SIMULINK.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%
% Before running this file, type  gainspc  to invoke the SIMULINK model,
% and arrange the windows with a tall MATLAB command window on the left
% and a tall Simulink window on the right - if you do not run the SIMULINK
% model first, the program will still run OK, but the SIMULINK windows
% may open over the top of the MATLAB one. You may then be unable to
% view the progrss reports, and it is a long wait till the end!
%
%

% vector of gains to be used in all possible pairings in diag([f11  f22]):
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% for Fig. 10.10 %%%%%%%%%%%%%%%%%%%%%%%%
%f=[-4:0.3:0 2 3 4.2:0.1:10  12 14 17 20 30 40 50];  % must be such that both
%            extremes are unstable, else sorting will fail
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
gainspc;  % call SIMULINK model into existence
pause(2)  % allow time for model to display on fast PCs
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% for Fig. 10.11 %%%%%%%%%%%%%%%%%%%%%%%%%
f=[-3:0.1:2 2.2:0.2:4 5:10];  % must be such that both
%            extremes are unstable, else sorting will fail
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
n=length(f);
test=-1*ones(n);   % initialise results matrix to -1
xplt=zeros(n,1);   % empty plotting arrays
yplt=zeros(n,2);
%
disp('')
disp('')
for ii = 1:n
   disp(['At loop ' int2str(ii)  ' out of ' int2str(n)...
                                            ' (accelerates to end)'])
   for jj = ii:n   % only need do upper triangle, due to symmetry
      nextgain=diag([f(ii)  f(jj)]);
      set_param('gainspc/F-B_Gain','D','nextgain');  % change f/b
      [a,b,c,d]=linmod('gainspc');
      test(ii,jj)=any(real(eig(a))>0);  % = 1 if unstable, 0 if stable
      test(jj,ii)=test(ii,jj);          % symmetrical part
   end
end
%
% Now got nxn test matrix where ones represent unstable gain combinations,
% and zeros stable ones.
%
% Find the transitions and plot. This assumes that the first element in each
% row will represent an unstable gain combination. The xplt vector is made
% equal to the set of gains, to represent the feedback gain in loop 1. 
% Then yplt(:,1) is found as the gain of loop 2 giving the transition from
% instability to stability at any given gain in xplt (loop 1), and yplt(:,2)
% is the (higher) gain in loop 2 giving the transition back to instability.
% If there is no such transition, yplt(:,2) is set to max.
%
xplt=f';
for ii=1:n
   if test(ii,1) ~= 1
      yplt(ii,1)=0;  % error condition - should not happen if f chosen well
      yplt(ii,2)=0;
   else
      st=find(test(ii,:)==0);   % find indices of all stable gains in loop 1 
      if isempty(st)
        yplt(ii,1)=f(n);  % never stable at this gain in loop1, set y to max
        yplt(ii,2)=f(n);
      else
        yplt(ii,1)=f(min(st));  % gain in loop 2 at which stability begins
        yplt(ii,2)=f(max(st));  % gain in loop 2 at which stability is lost
      end
   end
end
%
plot(xplt,yplt),grid
