% creates fig 10.27 - Step responses after INA + P+I

% Ken Dutton 1994
% MATLAB 5 doesn't allow ([],[],[],eye(2)) as a state-
% space model in mvfb.m, and produces warnings in mvser.m.
% Replaced with suitably-sized zero models, 6.1.99


disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')
disp(' Press any key after viewing these messages')
pause 

if ~exist('w') | ~exist('ap') | ~exist('k1') | ~exist('k2')
   disp(' ')
   disp(' ')
   disp('Running Fig10_25 first to generate data - please wait')
   fig10_25
end
%
% form combined compensator
k21=inv(k2*k1);     % Form the "real-world" compensator. Note that 
                    % inv(k2*k1) is the same as inv(k1)*inv(k2), which
                    % is in the correct order (against the signal flow
                    % in the real world). The inverses are necessary
                    % because k1 and k2 compensated the INVERSE Nyquist
                    % array.
%
% Input the TFM for default dc compensator:
%
%                                      (numerator polynimial matrix)
% Note that this must be in the form  -------------------------------
%                                     (common denominator polynomial)
%
% and all the numerator terms must be of the same length as the common
% denominator term. Therefore, zero elements must be entered as [0s + 0].
%
kdcnum=[1  1  0  0;0  0  1  1];  % polynomial num. matrix for compensator
kdccomden=[1  0];                % common denominator of compensator
[dca,dcb,dcc,dcd]=mvtf2ss(kdcnum,kdccomden); % convert compensator to s.space
%
% Now build state-space model for simulation:
[af,bf,cf,df]=mvser(0,[0 0],[0;0],k21,ap,bp,cp,dp); %cascade row-op comps w. plant
% swap for next 3 lines if i/ps are to be displayed
%ci=[cp;zeros(2,max(size(cp)))];
%di=[dp;eye(2)];
%[af,bf,cf,df]=series([],[],[],k21,ap,bp,ci,di);
%
[al,bl,cl,dl]=mvser(dca,dcb,dcc,dcd,af,bf,cf,df);  % cascade dc comp.
[a,b,c,d]=mvfb(al,bl,cl,dl,0,[0 0],[0;0],eye(2));  % add UNF loops 
% use next line instead if i/ps were included above
%[a,b,c,d]=feedback(al,bl,cl,dl,[],[],[],eye(2),-[1  2],[1  2]);  % add UNF 
%
t=[0:0.2:50];  %  time vector for plots
mv2step     % simulate - note that in this case the response is better
            % if a minimal state-space realisation is used (see fig10_23.m)
            % The following responses hardly change at all though.
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_27a
%
% matlab 3.5 print:
%meta fg10_27a
%!gpp fg10_27a /dhpgl /ol
%
% now repeat for tuned dc compensator:
%
% input TFM for dc compensator
kdcnum=[8  4  0  0;0  0  8  8];  % polynomial num. matrix for compensator
kdccomden=[1  0];                % common denominator of compensator
[dca,dcb,dcc,dcd]=mvtf2ss(kdcnum,kdccomden); % convert compensator to s.space
%
% Now build state-space model for simulation:
[af,bf,cf,df]=mvser(0,[0 0],[0;0],k21,ap,bp,cp,dp); %cascade row-op comps w. plant
%
[al,bl,cl,dl]=mvser(dca,dcb,dcc,dcd,af,bf,cf,df);  % cascade dc comp.
[a,b,c,d]=mvfb(al,bl,cl,dl,0,[0 0],[0;0],eye(2));  % add UNF loops 
%
t=[0:0.1:14];  %  time vector for plots
mv2step        % simulate
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_27b
%
% matlab 3.5 print:
%meta fg10_27b
%!gpp fg10_27b /dhpgl /ol
%
% version with inputs displayed:
ci=[cp;zeros(2,max(size(cp)))];
di=[dp;eye(2)];
[af,bf,cf,df]=series(0,[0 0],[0;0],k21,ap,bp,ci,di);
%
[al,bl,cl,dl]=mvser(dca,dcb,dcc,dcd,af,bf,cf,df);  % cascade dc comp.
[a,b,c,d]=feedback(al,bl,cl,dl,0,[0 0],[0;0],eye(2),-[1  2],[1  2]);  % add UNF 
%
t=[0:0.1:14];  %  time vector for plots
mv2step        % simulate
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_27c
%
% matlab 3.5 print:
%meta fg10_27c
%!gpp fg10_27c /dhpgl /ol
