% File fig10_30.m - Produces INA of Perron-Frobenius method for book

% Ken Dutton 1994
% finv replaced by mvfrinv.m, 6.1.99
% clg replaced by clf, 6.1.99
% MATLAB 5 doesn't allow ([],[],[],eye(2)) as a state-
% space model in mvfb.m. Replaced with suitably-sized
% zero models, 6.1.99


disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')
disp(' Press any key after viewing these messages')
pause 

if ~exist ('ap') | ~exist ('bp')
   disp(' ')
   disp('Running fig10_23  first to create plant model')
   disp(' ')
   fig10_23
end
if ~exist('w') | ~exist('kdpf') | ~exist('knpf')
   disp(' ')
   disp('Running fig10_29 first to create data - please wait')
   disp(' ')
   fig10_29
end
%
clc
disp('')
disp('Adding compensator')
%
% Loop 1 compensator is unity. knpf/kdpf is correct for loop 2 working
% with the INA (invert for real world later)
%
%              (numerator polynomial matrix)
% form TFM as -------------------------------
%             (common denominator polynomial)
%
% use kdpf as common denominator, and build numerator matrix, padding
% each term with leading zeros to same length as kdpf (1st order - 2 terms):
%
numpf=[kdpf 0  0; 0  0 knpf];      % numerator polynomial matrix
[a0,b0,c0,d0]=mvtf2ss(numpf,kdpf);            % st.-sp. version of compensator
[af,bf,cf,df]=mvser(a0,b0,c0,d0,ap,bp,cp,dp); % cascade with original plant
ifpf=(mvfrinv(w,mv2fr(af,bf,cf,df,w)));          % compensated inv. MVFR matrix
%
clf       % these two lines clear previous plots
hold off
%
inap4(w,ifpf,10,-50,50,0,1300)     % new INA
pause
inap4(w,ifpf,4,-1,3,-2,20)
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_30a
%
% matlab 3.5 print:
%meta fg10_30a
%!gpp fg10_30a /dhpgl /ol
%
% For real world, form the inverse of the P-F compensator, i.e. kdpf/knpf
kpfnum=[knpf 0 0; 0 0 kdpf];
kpfcden=knpf;
[pfa,pfb,pfc,pfd]=mvtf2ss(kpfnum,kpfcden); % convert to state-space.
%
%
% now try 'default' P+I:
% input TFM for dc compensator:
%
%                                      (numerator polynimial matrix)
% Note that this must be in the form  -------------------------------
%                                     (common denominator polynomial)
%
% and all the numerator terms must be of the same length as the common
% denominator term. Therefore, zero elements must be entered as [0s + 0].
%
kdcnum=[1  1  0  0;0  0  1  1]; % polynomial num. matrix for compensator
kdccomden=[1  0];                % common denominator of compensator
[dca,dcb,dcc,dcd]=mvtf2ss(kdcnum,kdccomden); % convert compensator to s.space
%
% Now build state-space model for simulation:
[af,bf,cf,df]=mvser(pfa,pfb,pfc,pfd,ap,bp,cp,dp); %cascade P-F comp. w. plant
% swap for next 3 lines if i/ps are to be displayed
%ci=[cp;zeros(2,max(size(cp)))];
%di=[dp;eye(2)];
%[af,bf,cf,df]=series(pfa,pfb,pfc,pfd,ap,bp,ci,di);
%
% step response without dc compensation. C.f. fig 10.26
[a,b,c,d]=mvfb(af,bf,cf,df,0,[0 0],[0;0],eye(2));  % add UNF loops 
% use next line instead if i/ps were included above
%[a,b,c,d]=feedback(af,bf,cf,df,[],[],[],eye(2),-[1  2],[1  2]);  % add UNF 
%
t=[0:0.2:50];  %  time vector for plots
mv2step        % simulate
%
[al,bl,cl,dl]=mvser(dca,dcb,dcc,dcd,af,bf,cf,df);  % cascade dc comp. into
                                                   % forward path
[a,b,c,d]=mvfb(al,bl,cl,dl,0,[0 0],[0;0],eye(2));  % add UNF loops 
% use next line instead if i/ps were included above
%[a,b,c,d]=feedback(al,bl,cl,dl,[],[],[],eye(2),-[1  2],[1  2]);  % add UNF 
%
t=[0:0.2:50];  %  time vector for plots
mv2step        % simulate
%
% now repeat for tuned compensator:
%
% input TFM for dc compensator
kdcnum=[8  4  0  0;0  0  4  4]; % polynomial num. matrix for compensator
kdccomden=[1  0];                % common denominator of compensator
[dca,dcb,dcc,dcd]=mvtf2ss(kdcnum,kdccomden); % convert compensator to s.space
%
% Now build state-space model for simulation:
[af,bf,cf,df]=mvser(pfa,pfb,pfc,pfd,ap,bp,cp,dp); %cascade P-F comp. w. plant
%
[al,bl,cl,dl]=mvser(dca,dcb,dcc,dcd,af,bf,cf,df);  % cascade dc comp.
[a,b,c,d]=mvfb(al,bl,cl,dl,0,[0 0],[0;0],eye(2));  % add UNF loops 
%
t=[0:0.1:14];  %  time vector for plots
mv2step        % simulate
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_30b
%
% matlab 3.5 print:
%meta fg10_30b
%!gpp fg10_30b /dhpgl /ol
%
% version with inputs displayed:
ci=[cp;zeros(2,max(size(cp)))];
di=[dp;eye(2)];
[af,bf,cf,df]=mvser(pfa,pfb,pfc,pfd,ap,bp,ci,di); %cascade P-F comp. w. plant
%
[al,bl,cl,dl]=mvser(dca,dcb,dcc,dcd,af,bf,cf,df);  % cascade dc comp.
[a,b,c,d]=feedback(al,bl,cl,dl,0,[0 0],[0;0],eye(2),-[1  2],[1  2]);  % add UNF 
%
t=[0:0.1:14];  %  time vector for plots
mv2step        % simulate
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig10_30c
%
% matlab 3.5 print:
%meta fg10_30c
%!gpp fg10_30c /dhpgl /ol
