% Fig11_9.  Intuitive self-tuning controller
% It closes the loop with unity negative feedback
% and gain only - and it runs the simulation.

% Bill Barraclough, 1995

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')
disp(' Press any key after viewing these messages')
pause 

% It measures the first peak height
% and first trough height.

% open-loop LTF (for mass = 1 kg)
num=40;

m=input('Mass ? ')
den=[m 10 20];

kt=input(' Enter the trial value of kt ');

% close the loop:
[ncl,dcl]=cloop(num*kt,den,-1);

ts=0.05;               % sampling interval
t=[0:100]*ts;          % time axis values for 100 points
[y,x]=step(ncl,dcl,t); % time response
plot(t,y);grid

disp(' ')
disp(' Response with test gain only is displayed.')
disp(' Press a key to continue')
pause;


[ymax1,nmax1]=max(y);       % max element of y and index into data set
bigmat=1e6*ones(nmax1,1);   % overwrite values of y up to first peak...
y([1:nmax1])=bigmat;        % with very large numbers
[ymin1,nmin1]=min(y);       % min element of y and index into data set
mm=ymax1/ymin1;             % peak value / trough value
thc=(nmin1-nmax1)*ts;       % period of half-cycle
fd=0.5/thc;                 % frequency (Hz)

% calculate PID parameters - see text
mmn=8-mm;                   % heuristic values throughout
fn=fd/((1-(mmn^3.5)/1110)^(1/3.5));
kus=kt/sqrt(1-mmn*mmn/55);
kc=0.5*kus;
td=0.25/fn;
ti=1/fn;

% Now try closed-loop control
n=40;             % number of 50ms samples to simulate
t=[0:n]*ts;       % new time axis
% add PID to forward path:
nc=[td 1 1/ti]*kc;
dc=[1 0];
nfp=conv(nc,num);
dfp=conv(dc,den);

% close the loop
[ncl,dcl]=cloop(nfp,dfp,-1);
 
u=ones(1,n+1);  % step input
nramp=5*td/ts;  % rate limit
ur=linspace(0,1,nramp);
u([1:nramp])=ur;
[y,x]=lsim(ncl,dcl,u,t);
   
plot(t,y);grid