% fig12_18.m - Designs optimal tracking controller for
% antenna-positioner.
%
% see in file fig12_14.m for more detailed comments

% Ken Dutton, 1993, 1996
% clg replaced with clf, 9.1.99
% last clg replaced with close, 9.1.99
% subplot(222) replaced with individual plot and pause, 9.1.99
% subplot(221) removed, 9.1.99


% State-space model:
a=[0  1  0; 0  -1  1; 0  0  -5];    b=[0  0   5]';   c=[1  0  0];   d=0;
t=[0:0.05:5];
%
r=1;			% single-input weighting (orig 1)
q=diag([4.5  0  0]);	% final state weightings (substitute your values)
titl=['Unit Step, Q=4.5/0/0, R=1, Orig, No Noise'];
[k,p,e]=lqr(a,b,q,r);                   %optimal design
k                                       % gains
e					% closed-loop eigenvalues
disp('')
disp('Press any key to continue')
pause
%
% At present, we have states x1, x2 and x3, and the single output y1.
% c is 1*2, and d scalar.
% Add states x1, x2 and x3 as outputs y2, y3 and y4, ready for fbk and plots:
[ap,bp,cp,dp]=augstate(a,b,c,d);
%
% Now cp will be 4*3, and dp will be 4*1. Next, add the input as y5 for plot:
cpi=[cp; 0  0  0]			% now 5*3 - listed to check
dpi=[dp;  1]				% now 5*1 - listed to check
%
% Connect SVF matrix, k, in the FORWARD path, so that the reference inputs are
% applied directly to the states at y2, y3 and y4, giving a TRACKING SYSTEM:
%
[af,bf,cf,df]=series([],[],[],k,ap,bp,cp,dp);		% makes fwd path
%
% add UNF from y2(=x1) to r1, y3(=x2) to r2 and y4(=x3) to r3:
%
[ac,bc,cc,dc]=feedback(af,bf,cf,df,[],[],[],eye(3),-[1  2  3],[2  3  4]);
%
%plot with input displayed:
%
% Connect SVF matrix, k, in the FORWARD path, so that the reference inputs are
% applied directly to the states at y2, y3 and y4, giving a TRACKING SYSTEM:
%
[af,bf,cf,df]=series([],[],[],k,ap,bp,cpi,dpi);		% makes fwd path
[ac,bc,cc,dc]=feedback(af,bf,cf,df,[],[],[],eye(3),-[1  2  3],[2  3  4]);  %UNF
%
clf
%titl='Control input and state responses';
titl=' ';
t2=[0:0.02:2];
disp('')
disp('Producing plots - press any key after viewing them')
step(ac,bc,cc,dc,1,t2),title(titl),grid 
pause
%
% separate plot of o/p to allow measurement of rise-time:
%
[yy,xx]=step(ac,bc,cc,dc,1,t);
plot(t,yy(:,1)),grid
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig12_18
%
% matlab 3.5 print:
%meta fig12_18
%!gpp fig12_18 /dhpgl /ol
%
%
% now plot o/p again to allow more accurate measurement:
clf
titl='Output response';
plot(t,yy(:,1)),grid,title(titl)
disp('')
disp('Position cursor on 10% level, press LH mouse button.')
disp('Repeat for 90% level.')
disp('Press return after reading this message,')
disp('and again after clicking on the two levels')
pause
[xxx,yyy]=ginput;
disp('')
disp('rise time s:')
tr=xxx(2)-xxx(1)
hold off
close
