% fig14_17.m - PPT for discontinuous example in fig. 14.16
%
% Nonlinearity is saturation at +/- 2, with slope 2
% Linear part is 1/(s(1+2s))
% Input is step of 4 units

% Ken Dutton, 1994

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')

%
% Use discrete-time state-space model, with x1 = y as o/p1 and 
% dx1/dt = dy/dt = x2 as o/p2


%
% state-space model and sampling interval:
a=[0  1;0  -1/2]; b=[0  1/2]'; ts=0.05; % c and d matrices not needed
%
% discrete-time version:
[phi,del]=c2d(a,b,ts);
%
% work out responses both with and without nonlinearity present:
xnl=[0  0]';  % nonlinear state responses - initial values
xnlold=xnl;
xlin=[0  0]'; % linear state responses - initial values
xlinold=xlin;
t=0;
u=4;          % input step
tend=20;      % experiment duration
ks=2;         % saturation level (+/- this)
gs=2;         % saturation gain
disp('')
disp('Calculating phase plane trajectories and simulating')
while t<tend
   t=[t  t(length(t))+ts];  % extend time vector by one step
   enl=gs*(u-xnlold(1));     % nonlinear system error
   elin=gs*(u-xlinold(1));   % linear system error
   if enl>ks        % saturation element
      enlsat=ks;
   elseif enl<-2
      enlsat=-ks;
   else
      enlsat=enl;
   end
   xnlold=phi*xnlold+del*enlsat;  % advance nonlinear responses one step
   xnl=[xnl  xnlold];     % add new state vector to response matrix
   xlinold=phi*xlinold+del*elin;  % advance linear responses one step
   xlin=[xlin  xlinold];  % add new state vector to response matrix
end
disp('')
disp('Plotting now')
subplot(211)                    % plot in top half of screen
plot(xlin(1,:),xlin(2,:)),grid  % linear response PPT plot (x2 vs x1)
hold on                     % superimpose...
plot(xnl(1,:),xnl(2,:))     % nonlinear response PPT plot (x2 vs x1)
subplot(212)           % plot in lower half of screen
plot(t,xlin),grid      % linear system time responses
hold on                % superimpose...
plot(t,xnl)            % nonlinear time responses
%print

%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig14_17
%
% matlab 3.5 print:
%meta fig14_17
%!gpp fig14_17 /dhpgl /ol
hold off
%clg
