% fig14_21.m - PPT for relay example in fig. 14.20
%
% N/Linearity is ideal relay
% Linear part is 3/(s(1+2s))
% Input is step
%
% Uses discrete time state-space model, with x1 as o/p1 and
% dx1/dt=x2 as o/p2.
%
% Use type fig14_21 for more detail

% Ken Dutton, 1994
% clg replaced with close, 9.1.99

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')

%
% NB very short ts needed for instantaneous relay. PPT is
% misleading if not.
% See comments at end for handling large data sets if ts is
% to be shorter than about 5ms over 20 seconds.
%
% state-space model by inspection:
a=[0  1;0  -1/2]; b=[0  3/2]';
%
% sample interval (plots in book were for ts=0.001 over 20sec)
ts=0.005;
%
% discrete-time state-space model:
[phi,del]=c2d(a,b,ts);
%
% experiment duration:
tend=20;
points=(tend/ts)+1;  % number of data points
%
% initialise all vectors and matrices to save execution time:
t=zeros(1,points);   % for time vector   
xnl=zeros(2,points); % for state vector
xnl(:,1)=[0 0]';     % initial nonlinear state responses
xnlold=xnl(:,1);
u=4;                 % step input
e=zeros(size(t));
edot=zeros(size(t));
e(1)=u-xnlold(1);    % initial error
edot(1)=-xnlold(2);  % and initial derivative
ndisp=0;             % counter for user progress display
for i=1:points
   if ndisp==0       % user progress display
      disp(['Reached '  num2str(i)  ', aiming at '  num2str(points)])
   end
   ndisp=ndisp+1;
   if ndisp==100, ndisp=0; end  % reset user display count every 100 steps
   enl=u-xnlold(1);     % nonlinear error
   if i>1  % skip first time (derivative calc. impossible - first
           %                             values inserted above).
      t(i)=t(i-1)+ts;
      e(i)=enl;
      edot(i)=(e(i)-e(i-1))/ts; % calculate derivative of error
   end;
   if enl>=0             % relay
      enlrla=1;
   else
      enlrla=-1;
   end
   xnlold=phi*xnlold+del*enlrla;     % advance nonlinear responses
   xnl(:,i)=xnlold;
end
%
% invoke next block of code if very large data files are in use,
% then run fdatprc to process them (more necessary for v3.5 than v4.2).
% Otherwise, use code block at the end to plot directly from this m-file
%
while 0  % comment-out this 'while' and 'end' to store data to floppy
   !erase fdatprc.mat
   save fdatprc xnl e edot t
   disp('')
   disp('')
   disp('Put a formatted floppy disk in drive a:')
   disp('')
   disp('The file fdatprc.mat will be copied to this disk and ')
   disp('then erased from the hard disk.')
   disp('')
   disp('Press any key when the disk is ready in drive a:')
   pause
   !copy fdatprc.mat a:
   !erase fdatprc.mat
   disp('')
   disp('type  fdatprc  at the MATLAB prompt to process the floppy')
   disp('disk and produce hpgl plot files.')
   disp('')
   disp('Press any key after noting this message')
   pause
end
%
% invoke the remainder for shorter data files (or MATLAB v4.2)
%while 0   % comment out this 'while' and 'end' to plot directly
   disp('')
   disp('Producing plot')
   disp('Press return to see simulation after viewing it')
   plot(e,edot),grid,title('e vs edot')
   pause
   %
   % matlab 4.2 print:
   %orient landscape
   %print -dhpgl fig14_21b
   %
   % matlab 3.5 print:
   %meta fig14_21b
   %!gpp fig14_21b /dhpgl /ol
   %
   plot(t,xnl(1,:)),grid,title('x1 vs time')
   pause
   %
   % matlab 4.2 print:
   %orient landscape
   %print -dhpgl fig14_21c
   %
   % matlab 3.5 print:
   %meta fig14_21c
   %!gpp fig14_21c /dhpgl /ol
%end
hold off
close