% fig14_22.m - PPT for relay example in fig. 14.20 plus switching delay
%
% N/L is relay with 100ms switching delay
% Linear part is 3/(s(1+2s))
% Input is step of size 4
%
% See in file fig14_21.m for more detailed comments

% Ken Dutton, 1994
% clg replaced with close, 9.1.99

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')

% Use disc. time s-s model, with x1 = y as o/p1 and dx1/dt=x2 as o/p2
%
a=[0  1;0  -1/2]; b=[0  3/2]'; ts=0.01;
[phi,del]=c2d(a,b,ts);
tswch=round(0.100/ts); % number of time steps by which to delay switching
tend=30;
points=(tend/ts)+1;
t=zeros(1,points);
xnl=zeros(2,points);
xnl(:,1)=[0  0]';            % initial nonlinear state responses
xnlold=xnl(:,1);
u=4;                         % step input
e=zeros(size(t));
edot=zeros(size(t));
e(1)=u-xnlold(1);            % initial error
edot(1)=-xnlold(2);          % and initial error derivative
ndisp=0;
enlrla=1*sign(e(1));         % initialise relay switching direction
if enlrla==0, enlrla=1; end  % (relay o/p cannot be zero)
swching=0;           % keeps track of steps during switching delays
for i=1:points
   if ndisp==0
      disp(['Reached '  num2str(i)  ', aiming at '  num2str(points)])
   end
   ndisp=ndisp+1;
   if ndisp==100, ndisp=0; end
%
   enl=u-xnlold(1);          % nonlinear error
   if i>1  % skip first time (deriv. calc. impossible - first values
           %                                    inserted above).
      t(i)=t(i-1)+ts;
      e(i)=enl;
      edot(i)=(e(i)-e(i-1))/ts;
   end;
   if enl>=0                 % relay:
      if enlrla==1           % already switched this way - no delay
         enlrla=1;
      elseif swching<tswch % relay just told to switch. Count out delay steps
          swching=swching+1; % (enlrla remains at -1)
      else                   % switching just completed
          swching=0;
          enlrla=1;
      end
   else
      if enlrla==-1          % already switched this way - no delay
         enlrla=-1;
      elseif swching<tswch % relay just told to switch. Count out delay steps
          swching=swching+1; % (enlrla remains at 1)
      else                   % switching just completed
          swching=0;
          enlrla=-1;
      end
   end
   xnlold=phi*xnlold+del*enlrla;   % advance nonlinear responses
   xnl(:,i)=xnlold;
end
%
% invoke next block of code if very large data files are in use,
% then run fdatprc to process them (more necessary for v3.5 than v4.2).
% Otherwise, use code block at the end to plot directly from this m-file
%
while 0  % comment-out this 'while' and 'end' to store data to floppy
   !erase fdatprc.mat
   save fdatprc xnl e edot t
   disp('')
   disp('')
   disp('Put a formatted floppy disk in drive a:')
   disp('')
   disp('The file fdatprc.mat will be copied to this disk and ')
   disp('then erased from the hard disk.')
   disp('')
   disp('Press any key when the disk is ready in drive a:')
   pause
   !copy fdatprc.mat a:
   !erase fdatprc.mat
   disp('')
   disp('type  fdatprc  at the MATLAB prompt to process the floppy')
   disp('disk and produce hpgl plot files.')
   disp('')
   disp('Press any key after noting this message')
   pause
end
%
% invoke the remainder for shorter data files (or MATLAB v4.2)
%while 0   % comment out this 'while' and 'end' to plot directly
   disp('')
   disp('Producing plot - press any key after viewing plots')
   subplot(211)  % plot in upper half of screen
   plot(e,edot),grid,title('e vs edot')
   subplot(212)  % plot in lower half of screen
   plot(t,xnl(1,:)),grid,title('x1 vs time')
   pause
   %
   % matlab 4.2 print:
   %orient landscape
   %print -dhpgl fig14_22
   %
   % matlab 3.5 print:
   %meta fig14_22
   %!gpp fig14_22 /dhpgl /ol
%end 
hold off
close