% fig14_30.m
%
% does nonlinear simulation to check lyapunov results
%
% File presently produces fig14.30(b). To get fig14.30(c),
% remove comments from five lines indicated %******.
%

% Ken Dutton, 1994
% clg replaced with close, 9.1.99

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')


% linear part of system:
%
a=[-4  0  1; 1  0  0; 1  0  0];
b=[1  0; 0  1; 0  0];  % define i/ps to x1 and x2 to allow
                       % addition of n/linearity
%
% discrete-time model for simulation:
%
ts=0.002;  % use 2ms sampling interval for fig14.30(b)
%
%******
%ts=0.008;  % use 8ms for fig14.30(c)
%
[phi,del]=c2d(a,b,ts);
%
% simulation:
%
tend=4;              % use 4s duration for fig14.30(b)
%
%******
%tend=15;            % use 15s duration for fig14.30(c)
%
points=tend/ts;      % number of data points
xnlold=[-1  1  -1]'; % initial nonlinear state responses
xnl=zeros(3,points+1); % initialise matrix to hold state vector
                       % (for plots) to zero to save execution time
xnl(:,1)=xnlold;
t=0;
ndisp=0;             % count for user progress display             
for i=1:points
   if ndisp==0       % user progress display
      disp(['Reached '  num2str(i)  ', aiming at '  num2str(points)])
   end
   ndisp=ndisp+1;
   if ndisp==100, ndisp=0; end % reset progress display every 100 steps
%
   t=[t  t(length(t))+ts];    % add next time value
   u1=-xnlold(1)*xnlold(2)^2; % nonlinear term for x1 dot
   u2=-xnlold(2)^2;           % nonlinear term for x2 dot
%
% comment out next two lines for fig14.30(b)
%
%******
%   u1=u1-2*xnlold(3);            % SVF for x1 dot
%   u2=u2-xnlold(1)-10*xnlold(2); % SVF for x2 dot
%
   xnlold=phi*xnlold+del*[u1  u2]';     % advance nonlinear responses
   xnl(:,i+1)=xnlold;
end
disp('')
disp('Producing plot - press any key after viewing plots')
plot(t,xnl);grid
pause
subplot(211)
%
% next line is for fig14.30(b) only, following one for fig14.30(c)
plot(t(1:1940),xnl(:,[1:1940])),grid % enough points for good plot
%******
%plot(t,xnl);grid
%
pause
disp('')
disp('To get Fig14.30(c), modify the m-file according to the comments')
disp('')
disp('Press any key to end')
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig14_30
%
% matlab 3.5 print:
%meta fig14_30
%!gpp fig14_30 /dhpgl /ol
hold off
close
