% fig14_37.m - describing function analysis for Fig14.37
%         (including simulation) (SIMULINK is far better for this)

% Ken Dutton, 1994
% warning about warnings removed!, 9.1.99
% pack command removed, 9.1.99
% grid moved from inverse Nyquist to DF plot command, 9.1.99
% version detection and plot clearing replaced with close, 9.1.99
% tend/ts replaced with round(tend/ts), 9.1.99
% zeros(ystor) replaced with zeros(size(ystor)), 9.1.99
% zeros(tplt) replaced with zeros(size(tplt)), 9.1.99

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key to continue after viewing a plot')
disp(' ')
disp(' Press any key after noting these messages')
disp(' ')
pause

% linear part of system:
%
clear  % needs a lot of memory
num=50;
den=conv([1  5  0],[1  1]);
%
% nonlinear part describing function (positive for now):
eb=0.1;                    % total backlash width
k=0.3;                     % slope of characteristic
em=[eb/2+0.0001:0.003:4];  % set of values of em from eb/2 to 4
%
% the following is a very restricted, and finely-stepped set
% of em values, which can be used to locate the first crossing
% point of the DF and inverse Nyquist plot:
%em=[eb/2+0.000001:0.00003:0.06];
%
eboem=eb.*em.^(-1);        % eb/em for use in DF equations
a1=-k*eb/pi*(2 - eboem);
b1=k/pi.*em.*(pi/2 + asin(1-eboem) + eboem.*(1-eboem).*sqrt(2.*eboem.^(-1)-1));
n=sqrt(a1.*a1 + b1.*b1).*em.^(-1);  % Describing Function magnitude
fi=atan(a1.*b1.^(-1));              % Describing Function angle
% now negate and convert to rectangular coordinates for plots:
dfre=-n.*cos(fi);
dfim=-n.*sin(fi);
%
% inverse nyquist of linear part of plant:
w=logspace(-3,1,500);
w=w(1:435);                   % range for good plot
[re,im]=nyquist(num,den,w);   % direct nyquist data
invden=re.*re + im.*im;       % denominator for inverse nyquist
invre=re.*invden.^(-1);       % real parts for inverse nyquist
invim=-im.*invden.^(-1);      % imag parts for inverse nyquist
disp('')
disp('Plotting now - press any key after viewing plots')
axis([-0.4,0,0,0.1]);
plot(invre,invim)             % inverse nyquist plot
axis([-0.4,0,0,0.1]);
hold on
plot(dfre,dfim),grid          % add describing function plot
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fg14_37b
%
% matlab 3.5 print:
%meta fg14_37b
%!gpp fg14_37b /dhpgl /ol
hold off
%
close  % allows progress display to be seen
%
% simulation to confirm limit cycle:
[a,b,c,d]=tf2ss(num,den); % state-space model of linear part
ts=0.01;                  % sampling interval
[phi,del]=c2d(a,b,ts);    % discrete-time state-space model
tend=70;                  % end time for simulation
points=round(tend/ts);           % number of data points
yold=0.06;                % initial conditions on the output
                          % (x3 is set to 1/50th of this below)
ystor=zeros(1,points+1);  % initialise vector to hold o/p values
ystor(1)=yold;
mold=0;                   % initial backlash output
mstor=zeros(1,points+1);  % initialise vector to hold backlash o/p values
mstor(1)=mold;
xold=[0  0  yold/50]';    % initial state values to start the simulation
t=zeros(size(ystor));           % initialise time vector
%
direxn=0;  % set to 1 after first hitting backlash in + dir, or -1 in - dir.
revers=0;  % set to -1 during + to - reversal, +1 during - to + reversal
ndisp=0;                  % user progress-display count
disp('')
disp('Simulating - press any key after viewing plots')
for i = 1:points+1
   if ndisp==0            % user progress display
      disp(['Reached '  num2str(i)  ', aiming at '  num2str(points+1)])
   end
   ndisp=ndisp+1;
   if ndisp==100, ndisp=0; end % reset progress display every 100 steps
   t(i+1)=t(i)+ts;        % new time value
   % backlash
   if direxn == 0   % not yet contacted - still in initial deadzone
      if abs(yold)<eb/2
         m=0;       % no backlash o/p whilst in initial deadzone
      else
         direxn=sign(yold);   % first time out of deadzone - set direction
         m=direxn*(abs(yold)-eb/2)*k;
      end
   elseif direxn==1 & ystor(i)>ystor(i-1)  % +ve motion, no reversal
      m=mold+k*(ystor(i)-ystor(i-1));
   elseif direxn==-1 & ystor(i)<ystor(i-1) % -ve motion, no reversal
      m=mold-k*(ystor(i-1)-ystor(i));
   elseif direxn==1 & ystor(i)<ystor(i-1) & revers==0 
      % was moving +ve, about to reverse to -ve
      revers=-1;
      yrev=ystor(i);  % memorise o/p level
   elseif direxn==-1 & ystor(i)>ystor(i-1) & revers==0
      % was moving -ve, about to reverse to +ve
      revers=1;
      yrev=ystor(i);  % memorise o/p level
   end
   %
   % generate constant output during reversals:
   if revers==-1     % reversing + to -
      if ystor(i) > yrev-eb
         m=mold; % still in deadband, hold at last value
      else           % reversal complete
         m=mold-k*(ystor(i-1)-ystor(i));
         revers=0;
         direxn=-1;
      end
   end
   if revers==1     % reversing - to +
      if ystor(i) < yrev+eb
         m=mold; % still in deadband, hold at last value
      else           % reversal complete
         m=mold+k*(ystor(i)-ystor(i-1));
         revers=0;
         direxn=1;
      end
   end
% feedback...
   u=-m;
   mold=m;
   mstor(i+1)=mold;       % add new value to vector of backlash o/p
   xnew=phi*xold+del*u;   % propagate states using discrete time model
   yold=c*xnew + d*u;  
   ystor(i+1)=yold;       % add new value to output vector for plotting
   xold=xnew;             % update the state vector for the next time step
end
%
% plot is too big for gpp in MATLAB 3.5. Therefore only plot say
% every 5th point:
disp('Preparing to plot - please wait')
extrct=[1:5:length(t)];   % indices of points to be plotted
tplt=zeros(1,length(extrct)); % initialise to zero
yplt=zeros(size(tplt));
mplt=zeros(size(tplt));
for i = 1:length(extrct)      % extract points
    tplt(i)=t(extrct(i));
    yplt(i)=ystor(extrct(i));
    mplt(i)=mstor(extrct(i));
end
plot(tplt,yplt,tplt,mplt),grid  % plot outputs vs. t
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fg14_37c
%
% matlab 3.5 print:
%meta fg14_37c
%!gpp fg14_37c /dhpgl /ol
hold off
