% Fig3_29.m - produces Fig. 3.29
%
% This file is written in such a way that the P, I
% and D settings can be altered easily by editing
% the file.  It does not just input the final
% values of the LTFs as suggested in the text,
% but calculates them from your settings.

% Ken Dutton, 1996

% Here are the PID settings. Just edit these (in a
% re-named copy of the original file) and save the
% altered file) for different experiments.

kp = 5;
ti = 1000000; % this must be > 999999 if not needed
td = 0;       % this must be zero if not needed

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')

% Open-loop plant LTF:
num = 6;
den = conv([1  1], conv([1  2],[1  3]));


if ti < 999999
   % PID controller LTF:
   % kp(1 + s.td + 1/s/ti) = kp(ti.td.s^2 + ti.s + 1)/(ti.s)
   numpid = kp*[ti*td  ti  1];
   denpid = [ti  0];
else
   % To avoid silly numbers etc., avoid including the large
   % ti term if no integral action is needed:
   % PD controller LTF:
   numpid = kp*[td  1];
   denpid = 1;
end

% Usually, this PID (or PD) cannot be used in simulation, as
% the numerator is higher order than the denominator.  However,
% in this case, since the plant is third order, with no
% numerator dynamics, the COMBINATION of the plant and
% controller is OK.  Therefore, form the forward path:

nfwdp = conv(numpid,num);
dfwdp = conv(denpid,den);

% Now add the UNF loop:
[nc,dc]=cloop(nfwdp,dfwdp,-1);

% check closed-loop LTF:
printsys(nc,dc)

% step response:
step(nc,dc);grid