% Creates responses for various values of  kT  for Fig. 7.5
%
% System is plant of k/s, with digital controller of gain 1, and
% unity negative feedback.
%
% Use   type fig7_5.m   for more detail.

% Ken Dutton 1996

% From Example 7.1,  Y(z)/R(z) = kT/(z - 1 + kT)
% so
%                    kTz^(-1)
% Y(z)/R(z) =  -------------------- 
%               1 - (1 - kT)z^(-1)             
%
% As a difference equation, therefore
%
% y(n) = (1 - kT)y(n-1) + kTr(n-1)
%
% The following code sets  kT = 0.5, then calculates the first 7 steps of the response
% kT = 1 is then selected for the next plot, and so on.
%
% The values are stored in successive columns of y.  y is initialised to set
% its size.  This is not necessary, but gives more efficient execution
% (which would matter for a larger number of steps).


disp(' ')
disp(' Five plots will be produced.  If you want to see them')
disp(' on the same screen, and you have MATLAB v4 or')
disp(' newer, see the comments inside the m-file.')
disp(' ')

kT=[0.5 1.0  1.5  2.0  2.1];     % values of kT to be tried
y=zeros(7,5);   % initialise size of y - also initialises first
                % step in each response to zero
r=1;     % unit step = 1 always

for k=1:5      % steps through values of  kT
   for n=2:7   % generates outputs at steps 2 to 7
      y(n,k) = (1 - kT(k))*y(n-1,k) + kT(k)*r;
   end
end

% The following plot commands will not work in MATLAB versions earlier
% than 4.0.  Removing the comments will make them active.

%subplot(321),plot(y(:,1),'x'),grid  % plot points as 'x' characters, against sample number
%title('kT = 0.5')
%subplot(322),plot(y(:,2),'x'),grid  % plot points as 'x' characters, against sample number
%title('kT = 1.0')
%subplot(323),plot(y(:,3),'x'),grid  % plot points as 'x' characters, against sample number
%title('kT = 1.5')
%subplot(324),plot(y(:,4),'x'),grid  % plot points as 'x' characters, against sample number
%title('kT = 2.0')
%subplot(325),plot(y(:,5),'x'),grid  % plot points as 'x' characters, against sample number
%title('kT = 2.1')
%disp(' ')
%disp(' Press a key to continue after viewing the plots')
%disp(' ')
%pause
%subplot(111)  % restore plot window to normal

% The following lines should work in any version of MATLAB

disp(' ')
disp(' The plots will appear one by one (the first should')
disp(' have appeared already)')
disp(' Press a key after viewing each one')
disp(' ')
plot(y(:,1),'x'),grid  % plot points as 'x' characters, against sample number
title('kT = 0.5')
pause
plot(y(:,2),'x'),grid  % plot points as 'x' characters, against sample number
title('kT = 1.0')
pause
plot(y(:,3),'x'),grid  % plot points as 'x' characters, against sample number
title('kT = 1.5')
pause
plot(y(:,4),'x'),grid  % plot points as 'x' characters, against sample number
title('kT = 2.0')
pause
plot(y(:,5),'x'),grid  % plot points as 'x' characters, against sample number
title('kT = 2.1')
pause

