% creates responses of antenna positioner, reduced-order observer and
% feedback loops (fig 9.14)
%
% values are from example 9.3

% Ken Dutton 1994
% clg replaced with clf, 8.1.99
% message about sequential plots added, 8.1.99

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Plots appear in sequence')
disp(' Press any key after viewing a plot')
disp(' ')

%
% plant:
clear
clf
hold off
a=[0  1  0; 0  -1  1; 0  0  -5]; b=[0  0  5]'; c=[1  0  0];
%
% observer:
f=[-35  1; -225  -5]; g=[-965  -8775]'; jo=[0  5]';
to=[-34  1  0; -225  0  1]; ksvf=[10  2.8 1.2];
ctinv=inv([c; to]);
%
% combine plant and observer into a single model with states [x  z]', and
% set up C and D to make plant states and observer o/p (Z) available:
ao=[a-b*ksvf   zeros(3,2); g*c-to*b*ksvf   f];
bo=[b; jo];
co=eye(5);
do=zeros(5,1);
%
% set up initial conditions w. plant o/p at 0.1 unit and observer at zero
x0=[0.1; 0; 0; 0; 0;];
%
% set up time and input vectors and simulate:
t=[0:1/100:12];         % time step 1/5 of observer time constants
u=zeros(length(t),1);  % initialise ref i/p of f/b loop to zero
stp=600;               % point of application of unit step
u([stp:length(t)],1)=ones((length(t)+1-stp),1); % step ref up to 1 unit
[y,x]=lsim(ao,bo,co,do,u,t,x0);
%
% y now has columns 1, 2 & 3 = x1, x2 and x3, columns 4 & 5 = z1 and z2.
% add cols. 6, 7 and 8 as estimates of x1, x2 and x3, and plot w. states:
est=zeros(length(t),3);
for k = 1:length(t)
   est(k,:)=[ctinv*[y(k,1); y(k,4); y(k,5)]]';
end
y=[y est];
plot(t,y(:,[1 2 3 6 7 8])),grid,xlabel('time (s)'), ylabel('amplitude')
pause
plot(t,y(:,[1 6])),grid,title('x1 & estimate')
pause
plot(t,y(:,[2 7])),grid,title('x2 & estimate')
pause
plot(t,y(:,[3 8])),grid,title('x3 & estimate')
pause
% now try half-plots (axis commands are only necessary for
%                     gpp in MATLAB v3.5)
subplot(221)
axis([0 6 -0.02 0.1]);
plot(t(1:stp),y((1:stp),[1 6])),grid,title('x1 & estimate')
subplot(222)
axis([0 6 -1 4]);
plot(t(1:stp),y((1:stp),[2 7])),grid,title('x2 & estimate')
subplot(223)
axis([0 6 -5 25]);
plot(t(1:stp),y((1:stp),[3 8])),grid,title('x3 & estimate')
subplot(224)
axis([6 12 -0.2 0.4]);
plot(t(stp+1:length(t)),y((stp+1:length(t)),[1 2 3 6 7 8])),grid,xlabel('time (s)'), ylabel('amplitude')
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_14
%
% matlab 3.5 print:
%meta fig9_14
%!gpp fig9_14 /dhpgl /ol
