% does MATLAB full-order observer design + SVF for example 9.3, 
% creates responses for figure 9.15
%
% values are from example 9.3

% Ken Dutton 1994
% clg replaced with clf, 8.1.99
% message about sequential plots added, 8.1.99

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Plots appear in sequence')
disp(' Press any key after viewing a plot')
disp(' ')

%
clf
hold off
clear
% plant state-space model:
a=[0  1  0; 0  -1  1; 0  0  -5];  b=[0  0  5]';  c=[1  0  0];  d=0;
%
% design feedback gain for f/back of estimated state vector:
clpols=[-1+2*j  -1-2*j  -10];  % closed-loop poles required
k=place(a,b,clpols);           % SVF design
%
% initially, design full-order observer & standard SVF - it's much easier!
%
% use dual of SVF pole-placement to fing observer gains (g matrix):
% three poles at -20 not allowed - use -19, -20 and -21 instead.
obspols=[-19 -20 -21];  % original observer poles for Fig. 9.14-type result
%
%  Add a comment marker (%) to the next line to give Fig 9.14-type result
obspols=[-1.4  -1.5  -1.6];  % initial errors much worse, step resp still OK!
g=place(a',c',obspols)';  % a' instead of a, c' instead of b
%                           designs transpose of observer gain
f=a-g*c;
%
% build system (from overall s-s description given below).
% Overall state vector is [x  xhat]'
%
ac=[a  -b*k; g*c  f-b*k];
bc=[b; b];
cc=eye(6);
dc=zeros(6,1);
%
% response:
%
% set up initial conditions w. plant o/p at 0.1 unit and observer at zero
x0=[0.1; 0; 0; 0; 0; 0];
%
% set up time and i/p vectors, simulate (see fig9_14.m for more general code):
t=[0:0.01:12];         % time step 1/5 of observer time constants
r=zeros(1201,1);       % initialise ref i/p of f/b loop to zero
r([600:1201],1)=ones(602,1); % step ref up to 1 unit
[y,x]=lsim(ac,bc,cc,dc,r,t,x0);
%
plot(t,y),grid
pause
plot(t,y(:,[1 4])),grid,title('x1 & estimate')
pause
plot(t,y(:,[2 5])),grid,title('x2 & estimate')
pause
plot(t,y(:,[3 6])),grid,title('x3 & estimate')
pause
% now try half-plots (axis commands are only necessary for
%                     gpp in MATLAB 3.5)
subplot(221)
axis([0 6 -0.05 0.15]);
plot(t(1:600),y((1:600),[1 4])),grid,title('x1 & estimate')
subplot(222)
axis([0 6 -0.2 0.3]);
plot(t(1:600),y((1:600),[2 5])),grid,title('x2 & estimate')
subplot(223)
axis([0 6 -1 0.2]);
plot(t(1:600),y((1:600),[3 6])),grid,title('x3 & estimate')
subplot(224)
axis([6 12 -0.2 0.4]);
plot(t(601:1201),y((601:1201),:)),grid,xlabel('time (s)'), ylabel('amplitude')
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_15
%
% matlab 3.5 print:
%meta fig9_15
%!gpp fig9_15 /dhpgl /ol
