% creates Kalman filter & responses for fig 9.22
%

% Ken Dutton 1994, 1996
% clg replaced with clf, 9.1.99
% version detection removed, 9.1.99
% final clg (now clf) removed, 9.1.99
% rand('normal') commented-out, 9.1.99
% rand(t') replaced with rand(length(t),1), 9.1.99
% warning about warnings removed, 9.1.99
% [xorg,xorg]=step(  replaced with  [xorg,yorg]=step( , 9.1.99
% colour sequences changed in plot titles as follows:
%    y to bu, v to gy, lb to r, r to c, g to m
%    db to y, y to bk, v to bu, 9.1.99

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing plots and results')
disp(' ')
disp(' Press any key after noting these comments')
pause


% This file first implements a noise-free design for comparison.
% to get to the Kalman filter part, go to %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% system model:
%

a=[0 1; 0 -1]; b=[0 1]'; c=[1 0]; d=0;
%
% We also need to make the states available as extra o/ps for plotting later
% (so that we can compare them with the estimates):
[ap,bp,cp,dp]=augstate(a,b,c,d);  % adds appropriate extra rows to cp and dp
%
% [ap, bp, cp, dp] now has 2 states, a single input, and three outputs. y1 is the
% original output, y2 is x1 and y3 is x2. type  cp  and  dp  at the MATLAB prompt
% if you want to confirm this.
%
% We also need a second input, feeding the o/p (y1) directly, to allow for
% a measurement noise i/p to be added:
bp=[bp  [0  0]'];     % adds extra input, u2, with no contribution to states.
dp=[dp  [1  0  0]'];  % makes new input u2 contribute to y1, but not y2 or y3.
%
% [ap, bp, cp, dp] now has 2 states, u1 feeds the ref i/p, u2 feeds y1 directly
% y1 is o/p = x1 (+noise later), y2=x1 (no noise), y3=x2.
%
% store noise-free step responses from i/p 1 for reference later:
h=0.05;
t=[0:h:10];
[xorg,yorg]=step(ap,bp,cp,dp,1,t);
disp(' ')
disp('Plotting now')
plot(t,xorg),grid,title('step on ref i/p - noise-free')
pause
%
while 0    % comment-out this (and the end statement to see noise input step responses)
   step(ap,bp,cp,dp,2,t),grid,title('step on output')
   pause
end
clf

%
% Define noise inputs:
u=zeros(length(t),2);   % initialise input streams to zero at every time step
%
%rand('normal') - obsolete under MATLAB 5
% noise:
u(:,2)=1.4142*rand(length(t),1); % o/p measurement noise (via input u2) at 1.4142V r.m.s.
m=mean(u(:,2));
u(:,2)=u(:,2)-m;   % ensures zero mean
u(:,1)=0.1*rand(length(t),1); % i/p noise at  0.1V r.m.s to corrupt u1
m=mean(u(:,1));   
u(:,1)=u(:,1)-m+1; % ensures zero mean noise, on 1V step
%
%
while 0 %%%%% comment-out (and  end  statement too) to try full order observer %%%%%%%
   %
   % Try a full-order observer.instead of the Kalman filter:
   %
   % At this point, change plant to discrete-time
   %
   [php,dlp]=c2d(ap,bp,h);
   %
 % experiment with these:
   obspols= [-3+3*j  -3-3*j];  % observer pole locations
   g=place(a',c',obspols)';        % design g for observer (dual of svf design)
   f=a-g*c;                        % design f for observer
   %
   %
   %
   % To allow series connection of the observer, define a 4th plant o/p, equal to
   % the reference i/p u1.
   %
   cp=[cp; [0 0]];      % now 4x2  (4 o/p, 2 states)
   dp=[dp; [1  0]];     % now 4x2  (4 o/p, 2 i/p)
   % 
   % Next define the observer to have four inputs: one from the ref i/p (now y4)
   % (to be fed in via b), one from the plant o/p (noisy version - y1) (to be
   % fed in via g) and two to allow the other plant states x1 and x2
   % (on y2 and y3) to be fed straight through the observer for plotting.
   % The series command can then be used to make the connection.
   %
   aobs=f;
   bobs=[g  zeros(2)  b];
   cobs=[zeros(3,2);  eye(2)]; % y1=orig. noisy o/p, y2:y3=x1,x2, y4:5 estimates
   dobs=[eye(3)  zeros(3,1);  zeros(2,4)];
   [pho,dlo]=c2d(aobs,bobs,h);   % discrete-time version
   [af,bf,cf,df]=series(php,dlp,cp,dp,pho,dlo,cobs,dobs);
   %
   % use next 4 lines for mismatched plant only:
      % for mismatched plant model, alter plant to something else:
      %apm=[0 1; 0 -2];  % use this in plant simulation only
      %[phpm,dlpm]=c2d(apm,bp,h);
      %[af,bf,cf,df]=series(phpm,dlpm,cp,dp,pho,dlo,cobs,dobs);
   %
   % use next 2 lines for mismatched o/p matrix only
      %cp(1,1)=2;
      %[af,bf,cf,df]=series(php,dlp,cp,dp,pho,dlo,cobs,dobs);
   %
   % The model [af,bf,cf,df] now includes the plant and full-order observer.
   % It has the original 2 states as x1:x2, and the estimates as x3:x4;
   % u1=ref i/p + noise, u2 feeds noise onto plant o/p y1;
   % y1=o/p (x1+u2), y2=x1, y3=x2, y4=x1hat, y5=x2hat.
   %
   % look at noise-free responses to check:
   dstep(af,bf,cf,df,1,length(t)),grid,
   title('FOO dstep on ref i/p - noise-free - y, x1, x2, x1hat, x2hat (bu, gy, r, c, m)')
   pause
   %
   while 0  % comment-out to see noise input step responses
      dstep(af,bf,cf,df,2,length(t)),grid,title('dstep on output')
      pause
   end
   %
   %
   dlsim(af,bf,cf,df,u),grid       % simulate the system with the noisy inputs
   title('FOO dlsim -  y, x1, x2, x1hat, x2hat (bu, gy, r, c, m)') 
   pause
   %
   % plot original noise-free and new states for comparison:
   [y,x]=dlsim(af,bf,cf,df,u);
   plot(t,[xorg  y]),grid
   title('FOO - noiseless y,x1,x2 + y,x1,x2,  x1hat,x2hat (bu,gy,r,c,m,y,bk,bu) - indiv. versions follow')
   pause
   plot(t,y(:,[2  4])),grid,title('FOO x1 and estimate  (bu, gy)')
   pause
   plot(t(1:100),y(1:100,[2  4])),grid,title('FOO x1 and estimate  (bu, gy)')
   pause
   plot(t,y(:,[3  5])),grid,title('FOO x2 and estimate  (bu, gy)')
   pause
   plot(t(1:100),y(1:100,[3  5])),grid,title('FOO x2 and estimate  (bu, gy)')
   pause
   clf

   %
   %
end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%
% now replace observer with Kalman filter 
%
% orig. plant model
a=[0 1; 0 -1]; b=[0 1]'; c=[1 0]; d=0;
%
% and we need a second input, feeding the o/p directly, to allow for noise i/p
ap=a;
cp=c;
bp=[b  [0  0]'];
dp=[d  1];  
%
% The model [ap,bp,cp,dp] has the original 2 states;
% u1=ref i/p, u2 feeds noise onto y1;
% y1=noisy o/p (x1+u2)
%
% We continue to use the discrete-time version [php, dlp, cp,dp] of the plant
%
[php,dlp]=c2d(ap,bp,h);
%
% use next 3 lines for mismatched plant only (also one line in main loop):
   % for mismatched plant model, alter plant to something else:
   %apm=[0 1; 0 -2];  % use this in plant simulation only
   %[phpm,dlpm]=c2d(apm,bp,h);
%
% Use next line for mismatched o/p matrix only (also 1 line in main loop)
   %cpm=cp; cpm(1,1)=2;
%
%
% Initialisations:
%
kkf=[0 0]';                   % kalman gain (doesn't need this - only done for
                              % consistency between runs)
pold=diag([10000 10000]);     % initial poor state estimation error covariance
xhatold=[u(1,2)  0]';         % initial filter estimates
q=0.01;                       % no noise on x1; x2 from definition
r=2;                          % from definition of measurement noise
gama=[0  1]';                 % no noise on x1
[pp,gama]=c2d(ap,gama,h);     % convert gama to discrete-time
xold=[0 0]';                  % initial plant states
ct=9;                         % iteration indicator for user progress display
y=zeros(length(t),5);         % initialise matrix to hold outputs for plotting, to
                              % zeros, to save execution time. o/p 1 is for y1,
                              % 2:3 for x1,x2, 4:5 for x1hat, x2hat
%
% iterate:
disp(' ')
disp('Calculating Kalman filter responses')
disp(' ')
for jj=1:length(t)
   ct=ct+1;
   if ct==10   % user progress display
      disp(['at loop ' int2str(jj) ' out of ' int2str(length(t)) ...
        ' gain = ' num2str(kkf(1)) '  ' num2str(kkf(2))])
      ct=0;
   end
   %
   % plant:
   %
   uplant=u(jj,:);                % inputs for this time step
   xnew=php*xold+dlp*uplant';     % state equation
   %
   % use next line for mismatched plant model only
      %xnew=phpm*xold+dlpm*uplant';
   %
   y(jj,1)=(cp*xnew+dp*uplant')'; % o/p equation
   %
   % use next line for mismatched o/p matrix only
      %y(jj,1)=(cpm*xnew+dp*uplant')';
   %
   y(jj,2:3)=xnew';               % store actual states for plotting
   %
   % Kalman filter:
   %
   pstar=php*pold*php' + gama*q*gama';         % Eq. 9.36
   kkf=pstar*cp'*inv(cp*pstar*cp' + r);        % Eq. 9.37
   xhatnew=(eye(2) - kkf*cp) * (php*xhatold + dlp*uplant') + kkf*y(jj,1);    % Eq. 9.38
   y(jj,4:5)=xhatnew';     % add state estimates as outputs for plotting
   pnew=(eye(2) - kkf*cp) * pstar;             % Eq. 9.39
   %
   % updates:
   %
   xold=xnew;
   xhatold=xhatnew;
   pold=pnew;
end
%
% plot original noise-free and new estimated states for comparison:
plot(t,[xorg  y]),grid
title('Noiseless y,x1,x2, noisy y,x1,x2, x1hat,x2hat (bu,gy,r,c,m,y,bk,bu)- indiv. versions follow')
pause
plot(t,[xorg(:,2) y(:,[1  2  4])]),grid,title('x1,  y,  noisy x1,  x1hat (bu, gy, r, c)')
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_22a
%
% matlab 3.5 print:
%meta fig9_22a
%!gpp fig9_22a /dhpgl /ol
%
plot(t,[xorg(:,3) y(:,[3  5])]),grid,title('x2,  noisy x2,  x2hat  (bu, gy, r)')
pause
%
% matlab 4.2 print:
%orient landscape
%print -dhpgl fig9_22b
%
% matlab 3.5 print:
%meta fig9_22b
%!gpp fig9_22b /dhpgl /ol
%
% Evaluate MATLAB version of Kalman filter gains to check:
%


[ll,pp,ee]=dlqe(php,gama,cp,q,r);
disp(' ')
disp('Kalman gain according to this program is:')
kkf
disp('Kalman gain according to MATLAB dlqe command is (press any key to continue):')
ll
pause
disp(' ')
disp('State estimate error covariance according to this program (final P matrix):')
pnew
disp('MATLAB dlqe command version:')
pp
