% Self-tuning PID controller simulation.
% There is no corresponding text book figure.

% The comments in  fig11_4.m  should be read to understand
% the code, which is quite similar in most places

% Ken Dutton & Bill Barraclough, 1996

disp(' ')
disp(' If the program pauses, try looking for a plot in a')
disp(' hidden window')
disp(' ')
disp(' Press any key after viewing a plot')
disp(' ')
disp(' The calculations may take a while')
disp(' ')
disp(' Press any key after viewing these messages')
pause 

disp(' ')
disp('The mass m will be 1.0 kg initially.')
disp('It will increase to 5 kg after 20 s')
disp('and reduce to 0.2 kg after 40 s.')
disp(' ')

% acquire the desired forgetting factor:
disp(' ')
ff=input(' Input the forgetting factor, recommended values 0.9 to 1.0 ');
if isempty(ff), ff=1.1;end  % allows the following 'if' statement to work
if ff>1
   disp(' Forgetting factor internally set to 1')
   ff=1;
elseif ff<0.5
   disp(' Forgetting factor is not allowed be less than 0.5 - is reset to 0.9')
   ff=0.9;
end

% select self-tuning or not?
disp(' ')
disp(' Press return to enable self-tuning.');
stg=input(' or enter a number to disable it ');
if isempty(stg)
   stg=1;
   disp('Self-tuning enabled')
else
   stg=0;
   disp('Self-tuning disabled')
end

% The plant (mass = 1 kg):
num=40;
den=[1 10 20];
ts=0.05;  
[bp,ap]=c2dm(num,den,ts);
ap=-ap(2:length(ap));
bp=bp(2:length(bp));  
q=length(bp);
p=length(ap);

% The digital PID controller
kc=2;       % Default PID parameters
ti=0.5;
td=0.1;

%rzn=2/0.66;   % Initial Ziegler-Nichols parameters
%lzn=0.059;

da=[1 0];
db(1)=kc*(1+td/ts+ts/ti);
db(2)=-kc*(1+2*td/ts);
db(3)=kc*td/ts;

pcvm=eye(p+q)*1000;  % Initial covariance
theta=ones(p+q,1);   % Initial parameters 
shift=[0 0 0 0
       1 0 0 0
       0 0 0 0
       0 0 1 0];
t20=round(20/ts);
t40=round(40/ts);
if t20 > 400
   t20=400;
   t40=800;
end
isteps=3*t20;
t=[1 : isteps]*ts;
y=0;
ev=[0 0]';     % vector of past errors
x=[0 0 0 0]';  % vector of past outputs stacked above vector of past inputs

nn=menu('Choose an input signal:','low-frequency square wave',...
                                  'single step','sinewave');
w=2*pi*0.1;  % radian frequency for 0.1 Hz
if nn==1, r=square(w*t);end        % data points for squarewave input
if nn==2, r=ones(1,isteps);end     % data points for single step input
if nn==3, r=sin(w*t);end           % data points for sinewave input


disp(' ')
disp(' Calculating responses - please wait')
disp(' (It can be quite some time!)')
pause(1)

for i1=1:isteps
   if i1==t20 
      m=5;
      den=[m 10 20];
      [bp,ap]=c2dm(num,den,ts);
      ap=-ap(2:length(ap));
      bp=bp(2:length(bp)); 
   end
   if i1==t40 
      m=0.2;
      den=[m 10 20];
      [bp,ap]=c2dm(num,den,ts);
      ap=-ap(2:length(ap));
      bp=bp(2:length(bp));
   end


   e = r(i1)-x(1);              % loop error
   % limit rate of change of error:
   if e-ev(1) > 0.5*ts
      e = ev(1)+0.5*ts;
   elseif e-ev(1) < -0.5*ts
      e = ev(1)-0.5*ts;
   end
   u = da*x(3:4) + db*[e; ev];  % digital controller
   y=ap*x(1:2) + bp*x(3:4);     % plant
   ev(2)=ev(1);
   ev(1)=e;
   uu(i1)=u; 
   yy(i1)=y;  

   a1(i1)=theta(1); % store last identified coefficients for plotting
   a2(i1)=theta(2);
   b1(i1)=theta(3);
   b2(i1)=theta(4);

   % Parameter identifer:
   temp=x'*pcvm;
   temp1=1 + temp*x;
   temp2=x'*theta - y;
   if temp1~=0
      temp3=pcvm*x*temp2/temp1;
      theta=theta-temp3;          % parameter estimate update
      temp4=x*x';
      temp5=pcvm*temp4;
      temp6=temp5*pcvm/temp1;
      pcvm=pcvm-temp6;            % covariance update
      pcvm=pcvm/ff;               % forgetting factor
   end

   x=shift*x;       % update vector of past outputs over inputs
   x(1)=y;
   x(3)=u;


   if stg==1 & i1>2
      % now re-tune the controller:

      % check for runaway parameter estimates:
      if abs(a1(i1))>0.98*abs(a1(i1-1))...
                      & abs(a1(i1))<1.02*abs(a1(i1-1))
         % generate the step response
         [yzn,xzn]=dstep(theta(3:4)',[1  -theta(1:2)'],50);
         % Now we find the maximum slope and the
         % value of time where it occurs.
         for ij=1:49;slp(ij)=(yzn(ij+1)-yzn(ij))/ts;end
         [mxsp,tsp]=max(slp);
         if mxsp>0 & mxsp<10 & tsp<48
            % Now we find the Ziegler-Nichols coefficients
            % K (kk), T2 (t2) and T1 (t1).
            kk=sum(theta(3:4))/sum([1  -theta(1:2)']); % d.c. gain
            if kk>0 & kk<20  % safety limits on d.c. gain
%               t2=kk/mxsp;
%               t1=(tsp)*ts - yzn(tsp)/mxsp;
               rzn=mxsp;
               lzn=(tsp)*ts - yzn(tsp)/mxsp;
               % Now we find the controller coefficients
               % Kc, Td and Ti.
%               if t1>0
%                  td = t1;
%                  ti = 4*t1;
%                  kc = .6*t2/(kk*t1);
                  kc=0.6/rzn/lzn;
                  td=lzn;
                  ti=4*lzn;
                  % Now digitise it (da is unchanged)
                  db(1)=kc*(1+td/ts+ts/ti);
                  db(2)=-kc*(1+2*td/ts);
                  db(3)=kc*td/ts;
%               end                   
            end
         end
      end
   end
end

plot(t,[a1'  a2'  b1'  b2']),grid
pause

subplot 311
plot(t,r),grid
axis([0 60 -2 2]);
subplot 312
plot(t,uu),grid
axis([0 60 -2 2]);
subplot 313
plot(t,yy),grid
axis([0 60 -2 2]);
subplot 111
